"""
Python module generated from Java source file java.util.concurrent.locks.ReentrantReadWriteLock

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util.concurrent import TimeUnit
from java.util.concurrent.locks import *
from jdk.internal.vm.annotation import ReservedStackAccess
from typing import Any, Callable, Iterable, Tuple


class ReentrantReadWriteLock(ReadWriteLock, Serializable):
    """
    An implementation of ReadWriteLock supporting similar
    semantics to ReentrantLock.
    This class has the following properties:
    
    
    - **Acquisition order**
    
    This class does not impose a reader or writer preference
    ordering for lock access.  However, it does support an optional
    *fairness* policy.
    
    <dl>
    <dt>***Non-fair mode (default)***
    <dd>When constructed as non-fair (the default), the order of entry
    to the read and write lock is unspecified, subject to reentrancy
    constraints.  A nonfair lock that is continuously contended may
    indefinitely postpone one or more reader or writer threads, but
    will normally have higher throughput than a fair lock.
    
    <dt>***Fair mode***
    <dd>When constructed as fair, threads contend for entry using an
    approximately arrival-order policy. When the currently held lock
    is released, either the longest-waiting single writer thread will
    be assigned the write lock, or if there is a group of reader threads
    waiting longer than all waiting writer threads, that group will be
    assigned the read lock.
    
    A thread that tries to acquire a fair read lock (non-reentrantly)
    will block if either the write lock is held, or there is a waiting
    writer thread. The thread will not acquire the read lock until
    after the oldest currently waiting writer thread has acquired and
    released the write lock. Of course, if a waiting writer abandons
    its wait, leaving one or more reader threads as the longest waiters
    in the queue with the write lock free, then those readers will be
    assigned the read lock.
    
    A thread that tries to acquire a fair write lock (non-reentrantly)
    will block unless both the read lock and write lock are free (which
    implies there are no waiting threads).  (Note that the non-blocking
    ReadLock.tryLock() and WriteLock.tryLock() methods
    do not honor this fair setting and will immediately acquire the lock
    if it is possible, regardless of waiting threads.)
    </dl>
    
    - **Reentrancy**
    
    This lock allows both readers and writers to reacquire read or
    write locks in the style of a ReentrantLock. Non-reentrant
    readers are not allowed until all write locks held by the writing
    thread have been released.
    
    Additionally, a writer can acquire the read lock, but not
    vice-versa.  Among other applications, reentrancy can be useful
    when write locks are held during calls or callbacks to methods that
    perform reads under read locks.  If a reader tries to acquire the
    write lock it will never succeed.
    
    - **Lock downgrading**
    Reentrancy also allows downgrading from the write lock to a read lock,
    by acquiring the write lock, then the read lock and then releasing the
    write lock. However, upgrading from a read lock to the write lock is
    **not** possible.
    
    - **Interruption of lock acquisition**
    The read lock and write lock both support interruption during lock
    acquisition.
    
    - **Condition support**
    The write lock provides a Condition implementation that
    behaves in the same way, with respect to the write lock, as the
    Condition implementation provided by
    ReentrantLock.newCondition does for ReentrantLock.
    This Condition can, of course, only be used with the write lock.
    
    The read lock does not support a Condition and
    `readLock().newCondition()` throws
    `UnsupportedOperationException`.
    
    - **Instrumentation**
    This class supports methods to determine whether locks
    are held or contended. These methods are designed for monitoring
    system state, not for synchronization control.
    
    
    Serialization of this class behaves in the same way as built-in
    locks: a deserialized lock is in the unlocked state, regardless of
    its state when serialized.
    
    **Sample usages.** Here is a code sketch showing how to perform
    lock downgrading after updating a cache (exception handling is
    particularly tricky when handling multiple locks in a non-nested
    fashion):
    
    ``` `class CachedData {
      Object data;
      boolean cacheValid;
      final ReentrantReadWriteLock rwl = new ReentrantReadWriteLock();
    
      void processCachedData() {
        rwl.readLock().lock();
        if (!cacheValid) {
          // Must release read lock before acquiring write lock
          rwl.readLock().unlock();
          rwl.writeLock().lock();
          try {
            // Recheck state because another thread might have
            // acquired write lock and changed state before we did.
            if (!cacheValid) {
              data = ...;
              cacheValid = True;`
            // Downgrade by acquiring read lock before releasing write lock
            rwl.readLock().lock();
          } finally {
            rwl.writeLock().unlock(); // Unlock write, still hold read
          }
        }
    
        try {
          use(data);
        } finally {
          rwl.readLock().unlock();
        }
      }
    }}```
    
    ReentrantReadWriteLocks can be used to improve concurrency in some
    uses of some kinds of Collections. This is typically worthwhile
    only when the collections are expected to be large, accessed by
    more reader threads than writer threads, and entail operations with
    overhead that outweighs synchronization overhead. For example, here
    is a class using a TreeMap that is expected to be large and
    concurrently accessed.
    
    ``` `class RWDictionary {
      private final Map<String, Data> m = new TreeMap<>();
      private final ReentrantReadWriteLock rwl = new ReentrantReadWriteLock();
      private final Lock r = rwl.readLock();
      private final Lock w = rwl.writeLock();
    
      public Data get(String key) {
        r.lock();
        try { return m.get(key);`
        finally { r.unlock(); }
      }
      public List<String> allKeys() {
        r.lock();
        try { return new ArrayList<>(m.keySet()); }
        finally { r.unlock(); }
      }
      public Data put(String key, Data value) {
        w.lock();
        try { return m.put(key, value); }
        finally { w.unlock(); }
      }
      public void clear() {
        w.lock();
        try { m.clear(); }
        finally { w.unlock(); }
      }
    }}```
    
    <h2>Implementation Notes</h2>
    
    This lock supports a maximum of 65535 recursive write locks
    and 65535 read locks. Attempts to exceed these limits result in
    Error throws from locking methods.

    Author(s)
    - Doug Lea

    Since
    - 1.5
    """

    def __init__(self):
        """
        Creates a new `ReentrantReadWriteLock` with
        default (nonfair) ordering properties.
        """
        ...


    def __init__(self, fair: bool):
        """
        Creates a new `ReentrantReadWriteLock` with
        the given fairness policy.

        Arguments
        - fair: `True` if this lock should use a fair ordering policy
        """
        ...


    def writeLock(self) -> "ReentrantReadWriteLock.WriteLock":
        ...


    def readLock(self) -> "ReentrantReadWriteLock.ReadLock":
        ...


    def isFair(self) -> bool:
        """
        Returns `True` if this lock has fairness set True.

        Returns
        - `True` if this lock has fairness set True
        """
        ...


    def getReadLockCount(self) -> int:
        """
        Queries the number of read locks held for this lock. This
        method is designed for use in monitoring system state, not for
        synchronization control.

        Returns
        - the number of read locks held
        """
        ...


    def isWriteLocked(self) -> bool:
        """
        Queries if the write lock is held by any thread. This method is
        designed for use in monitoring system state, not for
        synchronization control.

        Returns
        - `True` if any thread holds the write lock and
                `False` otherwise
        """
        ...


    def isWriteLockedByCurrentThread(self) -> bool:
        """
        Queries if the write lock is held by the current thread.

        Returns
        - `True` if the current thread holds the write lock and
                `False` otherwise
        """
        ...


    def getWriteHoldCount(self) -> int:
        """
        Queries the number of reentrant write holds on this lock by the
        current thread.  A writer thread has a hold on a lock for
        each lock action that is not matched by an unlock action.

        Returns
        - the number of holds on the write lock by the current thread,
                or zero if the write lock is not held by the current thread
        """
        ...


    def getReadHoldCount(self) -> int:
        """
        Queries the number of reentrant read holds on this lock by the
        current thread.  A reader thread has a hold on a lock for
        each lock action that is not matched by an unlock action.

        Returns
        - the number of holds on the read lock by the current thread,
                or zero if the read lock is not held by the current thread

        Since
        - 1.6
        """
        ...


    def hasQueuedThreads(self) -> bool:
        """
        Queries whether any threads are waiting to acquire the read or
        write lock. Note that because cancellations may occur at any
        time, a `True` return does not guarantee that any other
        thread will ever acquire a lock.  This method is designed
        primarily for use in monitoring of the system state.

        Returns
        - `True` if there may be other threads waiting to
                acquire the lock
        """
        ...


    def hasQueuedThread(self, thread: "Thread") -> bool:
        """
        Queries whether the given thread is waiting to acquire either
        the read or write lock. Note that because cancellations may
        occur at any time, a `True` return does not guarantee
        that this thread will ever acquire a lock.  This method is
        designed primarily for use in monitoring of the system state.

        Arguments
        - thread: the thread

        Returns
        - `True` if the given thread is queued waiting for this lock

        Raises
        - NullPointerException: if the thread is null
        """
        ...


    def getQueueLength(self) -> int:
        """
        Returns an estimate of the number of threads waiting to acquire
        either the read or write lock.  The value is only an estimate
        because the number of threads may change dynamically while this
        method traverses internal data structures.  This method is
        designed for use in monitoring system state, not for
        synchronization control.

        Returns
        - the estimated number of threads waiting for this lock
        """
        ...


    def hasWaiters(self, condition: "Condition") -> bool:
        """
        Queries whether any threads are waiting on the given condition
        associated with the write lock. Note that because timeouts and
        interrupts may occur at any time, a `True` return does
        not guarantee that a future `signal` will awaken any
        threads.  This method is designed primarily for use in
        monitoring of the system state.

        Arguments
        - condition: the condition

        Returns
        - `True` if there are any waiting threads

        Raises
        - IllegalMonitorStateException: if this lock is not held
        - IllegalArgumentException: if the given condition is
                not associated with this lock
        - NullPointerException: if the condition is null
        """
        ...


    def getWaitQueueLength(self, condition: "Condition") -> int:
        """
        Returns an estimate of the number of threads waiting on the
        given condition associated with the write lock. Note that because
        timeouts and interrupts may occur at any time, the estimate
        serves only as an upper bound on the actual number of waiters.
        This method is designed for use in monitoring of the system
        state, not for synchronization control.

        Arguments
        - condition: the condition

        Returns
        - the estimated number of waiting threads

        Raises
        - IllegalMonitorStateException: if this lock is not held
        - IllegalArgumentException: if the given condition is
                not associated with this lock
        - NullPointerException: if the condition is null
        """
        ...


    def toString(self) -> str:
        """
        Returns a string identifying this lock, as well as its lock state.
        The state, in brackets, includes the String `"Write locks ="`
        followed by the number of reentrantly held write locks, and the
        String `"Read locks ="` followed by the number of held
        read locks.

        Returns
        - a string identifying this lock, as well as its lock state
        """
        ...


    class ReadLock(Lock, Serializable):
        """
        The lock returned by method ReentrantReadWriteLock.readLock.
        """

        def lock(self) -> None:
            """
            Acquires the read lock.
            
            Acquires the read lock if the write lock is not held by
            another thread and returns immediately.
            
            If the write lock is held by another thread then
            the current thread becomes disabled for thread scheduling
            purposes and lies dormant until the read lock has been acquired.
            """
            ...


        def lockInterruptibly(self) -> None:
            """
            Acquires the read lock unless the current thread is
            Thread.interrupt interrupted.
            
            Acquires the read lock if the write lock is not held
            by another thread and returns immediately.
            
            If the write lock is held by another thread then the
            current thread becomes disabled for thread scheduling
            purposes and lies dormant until one of two things happens:
            
            
            
            - The read lock is acquired by the current thread; or
            
            - Some other thread Thread.interrupt interrupts
            the current thread.
            
            
            
            If the current thread:
            
            
            
            - has its interrupted status set on entry to this method; or
            
            - is Thread.interrupt interrupted while
            acquiring the read lock,
            
            
            
            then InterruptedException is thrown and the current
            thread's interrupted status is cleared.
            
            In this implementation, as this method is an explicit
            interruption point, preference is given to responding to
            the interrupt over normal or reentrant acquisition of the
            lock.

            Raises
            - InterruptedException: if the current thread is interrupted
            """
            ...


        def tryLock(self) -> bool:
            """
            Acquires the read lock only if the write lock is not held by
            another thread at the time of invocation.
            
            Acquires the read lock if the write lock is not held by
            another thread and returns immediately with the value
            `True`. Even when this lock has been set to use a
            fair ordering policy, a call to `tryLock()`
            *will* immediately acquire the read lock if it is
            available, whether or not other threads are currently
            waiting for the read lock.  This &quot;barging&quot; behavior
            can be useful in certain circumstances, even though it
            breaks fairness. If you want to honor the fairness setting
            for this lock, then use .tryLock(long, TimeUnit)
            tryLock(0, TimeUnit.SECONDS) which is almost equivalent
            (it also detects interruption).
            
            If the write lock is held by another thread then
            this method will return immediately with the value
            `False`.

            Returns
            - `True` if the read lock was acquired
            """
            ...


        def tryLock(self, timeout: int, unit: "TimeUnit") -> bool:
            """
            Acquires the read lock if the write lock is not held by
            another thread within the given waiting time and the
            current thread has not been Thread.interrupt
            interrupted.
            
            Acquires the read lock if the write lock is not held by
            another thread and returns immediately with the value
            `True`. If this lock has been set to use a fair
            ordering policy then an available lock *will not* be
            acquired if any other threads are waiting for the
            lock. This is in contrast to the .tryLock()
            method. If you want a timed `tryLock` that does
            permit barging on a fair lock then combine the timed and
            un-timed forms together:
            
            ``` `if (lock.tryLock() ||
                lock.tryLock(timeout, unit)) {
              ...`}```
            
            If the write lock is held by another thread then the
            current thread becomes disabled for thread scheduling
            purposes and lies dormant until one of three things happens:
            
            
            
            - The read lock is acquired by the current thread; or
            
            - Some other thread Thread.interrupt interrupts
            the current thread; or
            
            - The specified waiting time elapses.
            
            
            
            If the read lock is acquired then the value `True` is
            returned.
            
            If the current thread:
            
            
            
            - has its interrupted status set on entry to this method; or
            
            - is Thread.interrupt interrupted while
            acquiring the read lock,
            
             then InterruptedException is thrown and the
            current thread's interrupted status is cleared.
            
            If the specified waiting time elapses then the value
            `False` is returned.  If the time is less than or
            equal to zero, the method will not wait at all.
            
            In this implementation, as this method is an explicit
            interruption point, preference is given to responding to
            the interrupt over normal or reentrant acquisition of the
            lock, and over reporting the elapse of the waiting time.

            Arguments
            - timeout: the time to wait for the read lock
            - unit: the time unit of the timeout argument

            Returns
            - `True` if the read lock was acquired

            Raises
            - InterruptedException: if the current thread is interrupted
            - NullPointerException: if the time unit is null
            """
            ...


        def unlock(self) -> None:
            """
            Attempts to release this lock.
            
            If the number of readers is now zero then the lock
            is made available for write lock attempts. If the current
            thread does not hold this lock then IllegalMonitorStateException is thrown.

            Raises
            - IllegalMonitorStateException: if the current thread
            does not hold this lock
            """
            ...


        def newCondition(self) -> "Condition":
            """
            Throws `UnsupportedOperationException` because
            `ReadLocks` do not support conditions.

            Raises
            - UnsupportedOperationException: always
            """
            ...


        def toString(self) -> str:
            """
            Returns a string identifying this lock, as well as its lock state.
            The state, in brackets, includes the String `"Read locks ="`
            followed by the number of held read locks.

            Returns
            - a string identifying this lock, as well as its lock state
            """
            ...


    class WriteLock(Lock, Serializable):
        """
        The lock returned by method ReentrantReadWriteLock.writeLock.
        """

        def lock(self) -> None:
            """
            Acquires the write lock.
            
            Acquires the write lock if neither the read nor write lock
            are held by another thread
            and returns immediately, setting the write lock hold count to
            one.
            
            If the current thread already holds the write lock then the
            hold count is incremented by one and the method returns
            immediately.
            
            If the lock is held by another thread then the current
            thread becomes disabled for thread scheduling purposes and
            lies dormant until the write lock has been acquired, at which
            time the write lock hold count is set to one.
            """
            ...


        def lockInterruptibly(self) -> None:
            """
            Acquires the write lock unless the current thread is
            Thread.interrupt interrupted.
            
            Acquires the write lock if neither the read nor write lock
            are held by another thread
            and returns immediately, setting the write lock hold count to
            one.
            
            If the current thread already holds this lock then the
            hold count is incremented by one and the method returns
            immediately.
            
            If the lock is held by another thread then the current
            thread becomes disabled for thread scheduling purposes and
            lies dormant until one of two things happens:
            
            
            
            - The write lock is acquired by the current thread; or
            
            - Some other thread Thread.interrupt interrupts
            the current thread.
            
            
            
            If the write lock is acquired by the current thread then the
            lock hold count is set to one.
            
            If the current thread:
            
            
            
            - has its interrupted status set on entry to this method;
            or
            
            - is Thread.interrupt interrupted while
            acquiring the write lock,
            
            
            
            then InterruptedException is thrown and the current
            thread's interrupted status is cleared.
            
            In this implementation, as this method is an explicit
            interruption point, preference is given to responding to
            the interrupt over normal or reentrant acquisition of the
            lock.

            Raises
            - InterruptedException: if the current thread is interrupted
            """
            ...


        def tryLock(self) -> bool:
            """
            Acquires the write lock only if it is not held by another thread
            at the time of invocation.
            
            Acquires the write lock if neither the read nor write lock
            are held by another thread
            and returns immediately with the value `True`,
            setting the write lock hold count to one. Even when this lock has
            been set to use a fair ordering policy, a call to
            `tryLock()` *will* immediately acquire the
            lock if it is available, whether or not other threads are
            currently waiting for the write lock.  This &quot;barging&quot;
            behavior can be useful in certain circumstances, even
            though it breaks fairness. If you want to honor the
            fairness setting for this lock, then use .tryLock(long, TimeUnit) tryLock(0, TimeUnit.SECONDS)
            which is almost equivalent (it also detects interruption).
            
            If the current thread already holds this lock then the
            hold count is incremented by one and the method returns
            `True`.
            
            If the lock is held by another thread then this method
            will return immediately with the value `False`.

            Returns
            - `True` if the lock was free and was acquired
            by the current thread, or the write lock was already held
            by the current thread; and `False` otherwise.
            """
            ...


        def tryLock(self, timeout: int, unit: "TimeUnit") -> bool:
            """
            Acquires the write lock if it is not held by another thread
            within the given waiting time and the current thread has
            not been Thread.interrupt interrupted.
            
            Acquires the write lock if neither the read nor write lock
            are held by another thread
            and returns immediately with the value `True`,
            setting the write lock hold count to one. If this lock has been
            set to use a fair ordering policy then an available lock
            *will not* be acquired if any other threads are
            waiting for the write lock. This is in contrast to the .tryLock() method. If you want a timed `tryLock`
            that does permit barging on a fair lock then combine the
            timed and un-timed forms together:
            
            ``` `if (lock.tryLock() ||
                lock.tryLock(timeout, unit)) {
              ...`}```
            
            If the current thread already holds this lock then the
            hold count is incremented by one and the method returns
            `True`.
            
            If the lock is held by another thread then the current
            thread becomes disabled for thread scheduling purposes and
            lies dormant until one of three things happens:
            
            
            
            - The write lock is acquired by the current thread; or
            
            - Some other thread Thread.interrupt interrupts
            the current thread; or
            
            - The specified waiting time elapses
            
            
            
            If the write lock is acquired then the value `True` is
            returned and the write lock hold count is set to one.
            
            If the current thread:
            
            
            
            - has its interrupted status set on entry to this method;
            or
            
            - is Thread.interrupt interrupted while
            acquiring the write lock,
            
            
            
            then InterruptedException is thrown and the current
            thread's interrupted status is cleared.
            
            If the specified waiting time elapses then the value
            `False` is returned.  If the time is less than or
            equal to zero, the method will not wait at all.
            
            In this implementation, as this method is an explicit
            interruption point, preference is given to responding to
            the interrupt over normal or reentrant acquisition of the
            lock, and over reporting the elapse of the waiting time.

            Arguments
            - timeout: the time to wait for the write lock
            - unit: the time unit of the timeout argument

            Returns
            - `True` if the lock was free and was acquired
            by the current thread, or the write lock was already held by the
            current thread; and `False` if the waiting time
            elapsed before the lock could be acquired.

            Raises
            - InterruptedException: if the current thread is interrupted
            - NullPointerException: if the time unit is null
            """
            ...


        def unlock(self) -> None:
            """
            Attempts to release this lock.
            
            If the current thread is the holder of this lock then
            the hold count is decremented. If the hold count is now
            zero then the lock is released.  If the current thread is
            not the holder of this lock then IllegalMonitorStateException is thrown.

            Raises
            - IllegalMonitorStateException: if the current thread does not
            hold this lock
            """
            ...


        def newCondition(self) -> "Condition":
            """
            Returns a Condition instance for use with this
            Lock instance.
            The returned Condition instance supports the same
            usages as do the Object monitor methods (Object.wait() wait, Object.notify notify, and Object.notifyAll notifyAll) when used with the built-in
            monitor lock.
            
            
            
            - If this write lock is not held when any Condition method is called then an IllegalMonitorStateException is thrown.  (Read locks are
            held independently of write locks, so are not checked or
            affected. However it is essentially always an error to
            invoke a condition waiting method when the current thread
            has also acquired read locks, since other threads that
            could unblock it will not be able to acquire the write
            lock.)
            
            - When the condition Condition.await() waiting
            methods are called the write lock is released and, before
            they return, the write lock is reacquired and the lock hold
            count restored to what it was when the method was called.
            
            - If a thread is Thread.interrupt interrupted while
            waiting then the wait will terminate, an InterruptedException will be thrown, and the thread's
            interrupted status will be cleared.
            
            - Waiting threads are signalled in FIFO order.
            
            - The ordering of lock reacquisition for threads returning
            from waiting methods is the same as for threads initially
            acquiring the lock, which is in the default case not specified,
            but for *fair* locks favors those threads that have been
            waiting the longest.
            

            Returns
            - the Condition object
            """
            ...


        def toString(self) -> str:
            """
            Returns a string identifying this lock, as well as its lock
            state.  The state, in brackets includes either the String
            `"Unlocked"` or the String `"Locked by"`
            followed by the Thread.getName name of the owning thread.

            Returns
            - a string identifying this lock, as well as its lock state
            """
            ...


        def isHeldByCurrentThread(self) -> bool:
            """
            Queries if this write lock is held by the current thread.
            Identical in effect to ReentrantReadWriteLock.isWriteLockedByCurrentThread.

            Returns
            - `True` if the current thread holds this lock and
                    `False` otherwise

            Since
            - 1.6
            """
            ...


        def getHoldCount(self) -> int:
            """
            Queries the number of holds on this write lock by the current
            thread.  A thread has a hold on a lock for each lock action
            that is not matched by an unlock action.  Identical in effect
            to ReentrantReadWriteLock.getWriteHoldCount.

            Returns
            - the number of holds on this lock by the current thread,
                    or zero if this lock is not held by the current thread

            Since
            - 1.6
            """
            ...



"""
Python module generated from Java source file org.bukkit.MinecraftExperimental

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class MinecraftExperimental:
    """
    Indicates that the annotated element (class, method, field, etc.) is part of a
    <a href="https://minecraft.wiki/w/Experimental_Gameplay">minecraft experimental feature</a>
    and is subject to changes by Mojang.
    
    **Note:** Elements marked with this annotation require the use of a datapack or otherwise
    non-standard feature to be enabled on the server.

    See
    - <a href="https://www.minecraft.net/en-us/article/testing-new-minecraft-features/feature-toggles-java-edition">Features Toggles - Minecraft Article</a>
    """

    def value(self) -> "Requires":
        """
        Get the feature that must be enabled for the annotated object to be valid.
        
        While this value is not used anywhere in Bukkit, it is a convenience value to assist
        in locating relevant annotated elements for removal once no longer deemed an experimental
        feature by Minecraft. See Requires for information about use in plugins.

        Returns
        - the required feature flag
        """
        ...



"""
Python module generated from Java source file java.nio.file.StandardOpenOption

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from java.nio.file import *
from typing import Any, Callable, Iterable, Tuple


class StandardOpenOption(Enum):

    READ = 0
    """
    Open for read access.
    """
    WRITE = 1
    """
    Open for write access.
    """
    APPEND = 2
    """
    If the file is opened for .WRITE access then bytes will be written
    to the end of the file rather than the beginning.
    
     If the file is opened for write access by other programs, then it
    is file system specific if writing to the end of the file is atomic.
    """
    TRUNCATE_EXISTING = 3
    """
    If the file already exists and it is opened for .WRITE
    access, then its length is truncated to 0. This option is ignored
    if the file is opened only for .READ access.
    """
    CREATE = 4
    """
    Create a new file if it does not exist.
    This option is ignored if the .CREATE_NEW option is also set.
    The check for the existence of the file and the creation of the file
    if it does not exist is atomic with respect to other file system
    operations.
    """
    CREATE_NEW = 5
    """
    Create a new file, failing if the file already exists.
    The check for the existence of the file and the creation of the file
    if it does not exist is atomic with respect to other file system
    operations.
    """
    DELETE_ON_CLOSE = 6
    """
    Delete on close. When this option is present then the implementation
    makes a *best effort* attempt to delete the file when closed
    by the appropriate `close` method. If the `close` method is
    not invoked then a *best effort* attempt is made to delete the
    file when the Java virtual machine terminates (either normally, as
    defined by the Java Language Specification, or where possible, abnormally).
    This option is primarily intended for use with *work files* that
    are used solely by a single instance of the Java virtual machine. This
    option is not recommended for use when opening files that are open
    concurrently by other entities. Many of the details as to when and how
    the file is deleted are implementation specific and therefore not
    specified. In particular, an implementation may be unable to guarantee
    that it deletes the expected file when replaced by an attacker while the
    file is open. Consequently, security sensitive applications should take
    care when using this option.
    
     For security reasons, this option may imply the LinkOption.NOFOLLOW_LINKS option. In other words, if the option is present
    when opening an existing file that is a symbolic link then it may fail
    (by throwing java.io.IOException).
    """
    SPARSE = 7
    """
    Sparse file. When used with the .CREATE_NEW option then this
    option provides a *hint* that the new file will be sparse. The
    option is ignored when the file system does not support the creation of
    sparse files.
    """
    SYNC = 8
    """
    Requires that every update to the file's content or metadata be written
    synchronously to the underlying storage device.

    See
    - <a href="package-summary.html.integrity">Synchronized I/O file integrity</a>
    """
    DSYNC = 9
    """
    Requires that every update to the file's content be written
    synchronously to the underlying storage device.

    See
    - <a href="package-summary.html.integrity">Synchronized I/O file integrity</a>
    """



"""
Python module generated from Java source file org.spigotmc.CustomTimingsHandler

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import PrintStream
from java.util import Queue
from java.util.concurrent import ConcurrentLinkedQueue
from org.bukkit import Bukkit
from org.bukkit import World
from org.bukkit.command.defaults import TimingsCommand
from org.spigotmc import *
from typing import Any, Callable, Iterable, Tuple


class CustomTimingsHandler:
    """
    Provides custom timing sections for /timings merged.
    """

    def __init__(self, name: str):
        ...


    def __init__(self, name: str, parent: "CustomTimingsHandler"):
        ...


    @staticmethod
    def printTimings(printStream: "PrintStream") -> None:
        """
        Prints the timings and extra data to the given stream.

        Arguments
        - printStream: output stream
        """
        ...


    @staticmethod
    def reload() -> None:
        """
        Resets all timings.
        """
        ...


    @staticmethod
    def tick() -> None:
        """
        Ticked every tick by CraftBukkit to count the number of times a timer
        caused TPS loss.
        """
        ...


    def startTiming(self) -> None:
        """
        Starts timing to track a section of code.
        """
        ...


    def stopTiming(self) -> None:
        """
        Stops timing a section of code.
        """
        ...


    def reset(self) -> None:
        """
        Reset this timer, setting all values to zero.
        """
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.ForwardingListenableFuture

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import Preconditions
from com.google.common.util.concurrent import *
from java.util.concurrent import Executor
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ForwardingListenableFuture(ForwardingFuture, ListenableFuture):
    """
    A ListenableFuture which forwards all its method calls to another future. Subclasses
    should override one or more methods to modify the behavior of the backing future as desired per
    the <a href="http://en.wikipedia.org/wiki/Decorator_pattern">decorator pattern</a>.
    
    Most subclasses can just use SimpleForwardingListenableFuture.

    Author(s)
    - Shardul Deo

    Since
    - 4.0
    """

    def addListener(self, listener: "Runnable", exec: "Executor") -> None:
        ...


    class SimpleForwardingListenableFuture(ForwardingListenableFuture):
        """
        A simplified version of ForwardingListenableFuture where subclasses can pass in an
        already constructed ListenableFuture as the delegate.

        Since
        - 9.0
        """





"""
Python module generated from Java source file java.io.Closeable

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from java.io import IOException
from typing import Any, Callable, Iterable, Tuple


class Closeable(AutoCloseable):
    """
    A `Closeable` is a source or destination of data that can be closed.
    The close method is invoked to release resources that the object is
    holding (such as open files).

    Since
    - 1.5
    """

    def close(self) -> None:
        """
        Closes this stream and releases any system resources associated
        with it. If the stream is already closed then invoking this
        method has no effect.
        
         As noted in AutoCloseable.close(), cases where the
        close may fail require careful attention. It is strongly advised
        to relinquish the underlying resources and to internally
        *mark* the `Closeable` as closed, prior to throwing
        the `IOException`.

        Raises
        - IOException: if an I/O error occurs
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.Recipe

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.inventory import *
from typing import Any, Callable, Iterable, Tuple


class Recipe:
    """
    Represents some type of crafting recipe.
    """

    def getResult(self) -> "ItemStack":
        """
        Get the result of this recipe.

        Returns
        - The result stack
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.meta.PotionMeta

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Color
from org.bukkit.inventory.meta import *
from org.bukkit.potion import PotionData
from org.bukkit.potion import PotionEffect
from org.bukkit.potion import PotionEffectType
from org.bukkit.potion import PotionType
from typing import Any, Callable, Iterable, Tuple


class PotionMeta(ItemMeta):
    """
    Represents a potion or item that can have custom effects.
    """

    def setBasePotionData(self, data: "PotionData") -> None:
        """
        Sets the underlying potion data

        Arguments
        - data: PotionData to set the base potion state to

        Deprecated
        - Upgraded / extended potions are now their own PotionType use .setBasePotionType instead.
        """
        ...


    def getBasePotionData(self) -> "PotionData":
        """
        Returns the potion data about the base potion

        Returns
        - a PotionData object

        Deprecated
        - Upgraded / extended potions are now their own PotionType use .getBasePotionType() instead.
        """
        ...


    def setBasePotionType(self, type: "PotionType") -> None:
        """
        Sets the underlying potion type

        Arguments
        - type: PotionType to set the base potion state to
        """
        ...


    def getBasePotionType(self) -> "PotionType":
        """
        Returns the potion type about the base potion

        Returns
        - a PotionType object
        """
        ...


    def hasBasePotionType(self) -> bool:
        """
        Checks for the presence of a base potion type

        Returns
        - True if a base potion type is present
        """
        ...


    def hasCustomEffects(self) -> bool:
        """
        Checks for the presence of custom potion effects.

        Returns
        - True if custom potion effects are applied
        """
        ...


    def getCustomEffects(self) -> list["PotionEffect"]:
        """
        Gets an immutable list containing all custom potion effects applied to
        this potion.
        
        Plugins should check that hasCustomEffects() returns True before calling
        this method.

        Returns
        - the immutable list of custom potion effects
        """
        ...


    def addCustomEffect(self, effect: "PotionEffect", overwrite: bool) -> bool:
        """
        Adds a custom potion effect to this potion.

        Arguments
        - effect: the potion effect to add
        - overwrite: True if any existing effect of the same type should be
        overwritten

        Returns
        - True if the potion meta changed as a result of this call
        """
        ...


    def removeCustomEffect(self, type: "PotionEffectType") -> bool:
        """
        Removes a custom potion effect from this potion.

        Arguments
        - type: the potion effect type to remove

        Returns
        - True if the potion meta changed as a result of this call
        """
        ...


    def hasCustomEffect(self, type: "PotionEffectType") -> bool:
        """
        Checks for a specific custom potion effect type on this potion.

        Arguments
        - type: the potion effect type to check for

        Returns
        - True if the potion has this effect
        """
        ...


    def setMainEffect(self, type: "PotionEffectType") -> bool:
        """
        Moves a potion effect to the top of the potion effect list.
        
        This causes the client to display the potion effect in the potion's name.

        Arguments
        - type: the potion effect type to move

        Returns
        - True if the potion meta changed as a result of this call

        Deprecated
        - use .setBasePotionType(org.bukkit.potion.PotionType)
        """
        ...


    def clearCustomEffects(self) -> bool:
        """
        Removes all custom potion effects from this potion.

        Returns
        - True if the potion meta changed as a result of this call
        """
        ...


    def hasColor(self) -> bool:
        """
        Checks for existence of a potion color.

        Returns
        - True if this has a custom potion color
        """
        ...


    def getColor(self) -> "Color":
        """
        Gets the potion color that is set. A custom potion color will alter the
        display of the potion in an inventory slot.
        
        Plugins should check that hasColor() returns `True` before
        calling this method.

        Returns
        - the potion color that is set
        """
        ...


    def setColor(self, color: "Color") -> None:
        """
        Sets the potion color. A custom potion color will alter the display of
        the potion in an inventory slot.

        Arguments
        - color: the color to set
        """
        ...


    def hasCustomName(self) -> bool:
        """
        Checks for existence of a custom potion name translation suffix.

        Returns
        - True if this has a custom potion name
        """
        ...


    def getCustomName(self) -> str:
        """
        Gets the potion name translation suffix that is set.
        
        Plugins should check that hasCustomName() returns `True`
        before calling this method.

        Returns
        - the potion name that is set
        """
        ...


    def setCustomName(self, name: str) -> None:
        """
        Sets the potion name translation suffix.

        Arguments
        - name: the name to set
        """
        ...


    def clone(self) -> "PotionMeta":
        ...



"""
Python module generated from Java source file com.google.common.base.Stopwatch

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.base import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.j2objc.annotations import J2ObjCIncompatible
from java.time import Duration
from java.util.concurrent import TimeUnit
from typing import Any, Callable, Iterable, Tuple


class Stopwatch:
    """
    An object that accurately measures *elapsed time*: the measured duration between two
    successive readings of "now" in the same process.
    
    In contrast, *wall time* is a reading of "now" as given by a method like
    System.currentTimeMillis(), best represented as an java.time.Instant. Such values
    *can* be subtracted to obtain a `Duration` (such as by `Duration.between`), but
    doing so does *not* give a reliable measurement of elapsed time, because wall time readings
    are inherently approximate, routinely affected by periodic clock corrections. Because this class
    (by default) uses System.nanoTime, it is unaffected by these changes.
    
    Use this class instead of direct calls to System.nanoTime for two reasons:
    
    
      - The raw `long` values returned by `nanoTime` are meaningless and unsafe to use
          in any other way than how `Stopwatch` uses them.
      - An alternative source of nanosecond ticks can be substituted, for example for testing or
          performance reasons, without affecting most of your code.
    
    
    The one downside of `Stopwatch` relative to System.nanoTime() is that `Stopwatch` requires object allocation and additional method calls, which can reduce the accuracy
    of the elapsed times reported. `Stopwatch` is still suitable for logging and metrics where
    reasonably accurate values are sufficient. If the uncommon case that you need to maximize
    accuracy, use `System.nanoTime()` directly instead.
    
    Basic usage:
    
    ````Stopwatch stopwatch = Stopwatch.createStarted();
    doSomething();
    stopwatch.stop(); // optional
    
    Duration duration = stopwatch.elapsed();
    
    log.info("time: " + stopwatch); // formatted string like "12.3 ms"````
    
    The state-changing methods are not idempotent; it is an error to start or stop a stopwatch
    that is already in the desired state.
    
    When testing code that uses this class, use .createUnstarted(Ticker) or .createStarted(Ticker) to supply a fake or mock ticker. This allows you to simulate any valid
    behavior of the stopwatch.
    
    **Note:** This class is not thread-safe.
    
    **Warning for Android users:** a stopwatch with default behavior may not continue to keep
    time while the device is asleep. Instead, create one like this:
    
    ````Stopwatch.createStarted(
         new Ticker() {
           public long read() {
             return android.os.SystemClock.elapsedRealtimeNanos(); // requires API Level 17`
         });
    }```

    Author(s)
    - Kevin Bourrillion

    Since
    - 10.0
    """

    @staticmethod
    def createUnstarted() -> "Stopwatch":
        """
        Creates (but does not start) a new stopwatch using System.nanoTime as its time source.

        Since
        - 15.0
        """
        ...


    @staticmethod
    def createUnstarted(ticker: "Ticker") -> "Stopwatch":
        """
        Creates (but does not start) a new stopwatch, using the specified time source.

        Since
        - 15.0
        """
        ...


    @staticmethod
    def createStarted() -> "Stopwatch":
        """
        Creates (and starts) a new stopwatch using System.nanoTime as its time source.

        Since
        - 15.0
        """
        ...


    @staticmethod
    def createStarted(ticker: "Ticker") -> "Stopwatch":
        """
        Creates (and starts) a new stopwatch, using the specified time source.

        Since
        - 15.0
        """
        ...


    def isRunning(self) -> bool:
        """
        Returns `True` if .start() has been called on this stopwatch, and .stop()
        has not been called since the last call to `start()`.
        """
        ...


    def start(self) -> "Stopwatch":
        """
        Starts the stopwatch.

        Returns
        - this `Stopwatch` instance

        Raises
        - IllegalStateException: if the stopwatch is already running.
        """
        ...


    def stop(self) -> "Stopwatch":
        """
        Stops the stopwatch. Future reads will return the fixed duration that had elapsed up to this
        point.

        Returns
        - this `Stopwatch` instance

        Raises
        - IllegalStateException: if the stopwatch is already stopped.
        """
        ...


    def reset(self) -> "Stopwatch":
        """
        Sets the elapsed time for this stopwatch to zero, and places it in a stopped state.

        Returns
        - this `Stopwatch` instance
        """
        ...


    def elapsed(self, desiredUnit: "TimeUnit") -> int:
        """
        Returns the current elapsed time shown on this stopwatch, expressed in the desired time unit,
        with any fraction rounded down.
        
        **Note:** the overhead of measurement can be more than a microsecond, so it is generally
        not useful to specify TimeUnit.NANOSECONDS precision here.
        
        It is generally not a good idea to use an ambiguous, unitless `long` to represent
        elapsed time. Therefore, we recommend using .elapsed() instead, which returns a
        strongly-typed `Duration` instance.

        Since
        - 14.0 (since 10.0 as `elapsedTime()`)
        """
        ...


    def elapsed(self) -> "Duration":
        """
        Returns the current elapsed time shown on this stopwatch as a Duration. Unlike .elapsed(TimeUnit), this method does not lose any precision due to rounding.

        Since
        - 22.0
        """
        ...


    def toString(self) -> str:
        """
        Returns a string representation of the current elapsed time.
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.ImmutableEnumMap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from com.google.common.collect.ImmutableMap import IteratorBasedImmutableMap
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import Serializable
from java.util import EnumMap
from java.util import Spliterator
from java.util.function import BiConsumer
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class ImmutableEnumMap(IteratorBasedImmutableMap):
    """
    Implementation of ImmutableMap backed by a non-empty java.util.EnumMap.

    Author(s)
    - Louis Wasserman
    """

    def size(self) -> int:
        ...


    def containsKey(self, key: "Object") -> bool:
        ...


    def get(self, key: "Object") -> "V":
        ...


    def equals(self, object: "Object") -> bool:
        ...


    def forEach(self, action: "BiConsumer"["K", "V"]) -> None:
        ...



"""
Python module generated from Java source file com.google.common.base.CaseFormat

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import *
from enum import Enum
from java.io import Serializable
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class CaseFormat(Enum):
    """
    Utility class for converting between various ASCII case formats. Behavior is undefined for
    non-ASCII input.

    Author(s)
    - Mike Bostock

    Since
    - 1.0
    """

    LOWER_HYPHEN = (CharMatcher.is('-'), "-")
    """
    Hyphenated variable naming convention, e.g., "lower-hyphen".
    """
    LOWER_UNDERSCORE = (CharMatcher.is('_'), "_")
    """
    C++ variable naming convention, e.g., "lower_underscore".
    """
    LOWER_CAMEL = (CharMatcher.inRange('A', 'Z'), "")
    """
    Java variable naming convention, e.g., "lowerCamel".
    """
    UPPER_CAMEL = (CharMatcher.inRange('A', 'Z'), "")
    """
    Java and C++ class naming convention, e.g., "UpperCamel".
    """
    UPPER_UNDERSCORE = (CharMatcher.is('_'), "_")
    """
    Java and C++ constant naming convention, e.g., "UPPER_UNDERSCORE".
    """


    def to(self, format: "CaseFormat", str: str) -> str:
        """
        Converts the specified `String str` from this format to the specified `format`. A
        "best effort" approach is taken; if `str` does not conform to the assumed format, then
        the behavior of this method is undefined but we make a reasonable effort at converting anyway.
        """
        ...


    def converterTo(self, targetFormat: "CaseFormat") -> "Converter"[str, str]:
        """
        Returns a serializable `Converter` that converts strings from this format to `targetFormat`.

        Since
        - 16.0
        """
        ...



"""
Python module generated from Java source file org.bukkit.Tag

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import *
from org.bukkit.entity import EntityType
from typing import Any, Callable, Iterable, Tuple


class Tag(Keyed):
    """
    Represents a tag that may be defined by the server or a resource pack to
    group like things together.
    
    Note that whilst all tags defined within this interface must be present in
    implementations, their existence is not guaranteed across future versions.
    
    Type `<T>`: the type of things grouped by this tag
    """

    REGISTRY_BLOCKS = "blocks"
    """
    Key for the built in block registry.
    """
    WOOL = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("wool"), Material.class)
    """
    Vanilla block tag representing all colors of wool.
    """
    PLANKS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("planks"), Material.class)
    """
    Vanilla block tag representing all plank variants.
    """
    STONE_BRICKS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("stone_bricks"), Material.class)
    """
    Vanilla block tag representing all regular/mossy/cracked/chiseled stone
    bricks.
    """
    WOODEN_BUTTONS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("wooden_buttons"), Material.class)
    """
    Vanilla block tag representing all wooden buttons.
    """
    STONE_BUTTONS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("stone_buttons"), Material.class)
    """
    Vanilla block tag representing all stone buttons.
    """
    BUTTONS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("buttons"), Material.class)
    """
    Vanilla block tag representing all buttons (inherits from
    .WOODEN_BUTTONS.
    """
    WOOL_CARPETS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("wool_carpets"), Material.class)
    """
    Vanilla block tag representing all colors of carpet.
    """
    CARPETS = WOOL_CARPETS
    """
    Deprecated
    - .WOOL_CARPETS.
    """
    WOODEN_DOORS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("wooden_doors"), Material.class)
    """
    Vanilla block tag representing all wooden doors.
    """
    MOB_INTERACTABLE_DOORS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("mob_interactable_doors"), Material.class)
    """
    Vanilla block tag representing all doors which can be opened by mobs.
    """
    WOODEN_STAIRS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("wooden_stairs"), Material.class)
    """
    Vanilla block tag representing all wooden stairs.
    """
    WOODEN_SLABS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("wooden_slabs"), Material.class)
    """
    Vanilla block tag representing all wooden slabs.
    """
    WOODEN_FENCES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("wooden_fences"), Material.class)
    """
    Vanilla block tag representing all wooden fences.
    """
    PRESSURE_PLATES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("pressure_plates"), Material.class)
    """
    Vanilla block tag representing all pressure plates.
    """
    WOODEN_PRESSURE_PLATES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("wooden_pressure_plates"), Material.class)
    """
    Vanilla block tag representing all wooden pressure plates.
    """
    STONE_PRESSURE_PLATES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("stone_pressure_plates"), Material.class)
    """
    Vanilla block tag representing all stone pressure plates.
    """
    WOODEN_TRAPDOORS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("wooden_trapdoors"), Material.class)
    """
    Vanilla block tag representing all wooden trapdoors.
    """
    DOORS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("doors"), Material.class)
    """
    Vanilla block tag representing all doors (inherits from
    .WOODEN_DOORS.
    """
    SAPLINGS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("saplings"), Material.class)
    """
    Vanilla block tag representing all sapling variants.
    """
    LOGS_THAT_BURN = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("logs_that_burn"), Material.class)
    """
    Vanilla block tag representing all log and bark variants that burn.
    """
    LOGS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("logs"), Material.class)
    """
    Vanilla block tag representing all log and bark variants.
    """
    DARK_OAK_LOGS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("dark_oak_logs"), Material.class)
    """
    Vanilla block tag representing all dark oak log and bark variants.
    """
    PALE_OAK_LOGS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("pale_oak_logs"), Material.class)
    """
    Vanilla block tag representing all pale oak log and bark variants.
    """
    OAK_LOGS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("oak_logs"), Material.class)
    """
    Vanilla block tag representing all oak log and bark variants.
    """
    BIRCH_LOGS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("birch_logs"), Material.class)
    """
    Vanilla block tag representing all birch log and bark variants.
    """
    ACACIA_LOGS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("acacia_logs"), Material.class)
    """
    Vanilla block tag representing all acacia log and bark variants.
    """
    CHERRY_LOGS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("cherry_logs"), Material.class)
    """
    Vanilla block tag representing all cherry log and bark variants.
    """
    JUNGLE_LOGS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("jungle_logs"), Material.class)
    """
    Vanilla block tag representing all jungle log and bark variants.
    """
    SPRUCE_LOGS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("spruce_logs"), Material.class)
    """
    Vanilla block tag representing all spruce log and bark variants.
    """
    MANGROVE_LOGS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("mangrove_logs"), Material.class)
    """
    Vanilla block tag representing all mangrove log and bark variants.
    """
    CRIMSON_STEMS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("crimson_stems"), Material.class)
    """
    Vanilla block tag representing all crimson stems.
    """
    WARPED_STEMS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("warped_stems"), Material.class)
    """
    Vanilla block tag representing all warped stems.
    """
    BAMBOO_BLOCKS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("bamboo_blocks"), Material.class)
    """
    Vanilla block tag representing all bamboo blocks.
    """
    BANNERS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("banners"), Material.class)
    """
    Vanilla block tag representing all banner blocks.
    """
    SAND = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("sand"), Material.class)
    """
    Vanilla block tag representing all sand blocks.
    """
    SMELTS_TO_GLASS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("smelts_to_glass"), Material.class)
    """
    Vanilla block tag representing all blocks which smelt to glass in a furnace.
    """
    STAIRS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("stairs"), Material.class)
    """
    Vanilla block tag representing all stairs.
    """
    SLABS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("slabs"), Material.class)
    """
    Vanilla block tag representing all slabs.
    """
    WALLS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("walls"), Material.class)
    """
    Vanilla block tag representing all walls.
    """
    ANVIL = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("anvil"), Material.class)
    """
    Vanilla block tag representing all damaged and undamaged anvils.
    """
    RAILS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("rails"), Material.class)
    """
    Vanilla block tag representing all Minecart rails.
    """
    LEAVES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("leaves"), Material.class)
    """
    Vanilla block tag representing all leaves fans.
    """
    TRAPDOORS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("trapdoors"), Material.class)
    """
    Vanilla block tag representing all trapdoors (inherits from
    .WOODEN_TRAPDOORS.
    """
    FLOWER_POTS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("flower_pots"), Material.class)
    """
    Vanilla block tag representing all empty and filled flower pots.
    """
    SMALL_FLOWERS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("small_flowers"), Material.class)
    """
    Vanilla block tag representing all small flowers.
    """
    BEDS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("beds"), Material.class)
    """
    Vanilla block tag representing all beds.
    """
    FENCES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("fences"), Material.class)
    """
    Vanilla block tag representing all fences.
    """
    FLOWERS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("flowers"), Material.class)
    """
    Vanilla block tag representing all flowers.
    """
    BEE_ATTRACTIVE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("bee_attractive"), Material.class)
    """
    Vanilla block tag representing all blocks which attract bees.
    """
    PIGLIN_REPELLENTS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("piglin_repellents"), Material.class)
    """
    Vanilla block tag representing all piglin repellents.
    """
    GOLD_ORES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("gold_ores"), Material.class)
    """
    Vanilla block tag representing all gold ores.
    """
    IRON_ORES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("iron_ores"), Material.class)
    """
    Vanilla block tag representing all iron ores.
    """
    DIAMOND_ORES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("diamond_ores"), Material.class)
    """
    Vanilla block tag representing all diamond ores.
    """
    REDSTONE_ORES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("redstone_ores"), Material.class)
    """
    Vanilla block tag representing all redstone ores.
    """
    LAPIS_ORES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("lapis_ores"), Material.class)
    """
    Vanilla block tag representing all lapis ores.
    """
    COAL_ORES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("coal_ores"), Material.class)
    """
    Vanilla block tag representing all coal ores.
    """
    EMERALD_ORES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("emerald_ores"), Material.class)
    """
    Vanilla block tag representing all emerald ores.
    """
    COPPER_ORES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("copper_ores"), Material.class)
    """
    Vanilla block tag representing all copper ores.
    """
    CANDLES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("candles"), Material.class)
    """
    Vanilla block tag representing all candles.
    """
    DIRT = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("dirt"), Material.class)
    """
    Vanilla block tag representing all dirt.
    """
    TERRACOTTA = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("terracotta"), Material.class)
    """
    Vanilla block tag representing all terracotta.
    """
    BADLANDS_TERRACOTTA = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("badlands_terracotta"), Material.class)
    """
    Vanilla block tag representing all badlands terracotta.
    """
    CONCRETE_POWDER = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("concrete_powder"), Material.class)
    """
    Vanilla block tag representing all concrete powder.
    """
    COMPLETES_FIND_TREE_TUTORIAL = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("completes_find_tree_tutorial"), Material.class)
    """
    Vanilla block tag representing all blocks which complete the find tree
    tutorial.
    """
    ENDERMAN_HOLDABLE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("enderman_holdable"), Material.class)
    """
    Vanilla block tag denoting blocks that enderman may pick up and hold.
    """
    ICE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("ice"), Material.class)
    """
    Vanilla block tag denoting ice blocks.
    """
    VALID_SPAWN = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("valid_spawn"), Material.class)
    """
    Vanilla block tag denoting all valid mob spawn positions.
    """
    IMPERMEABLE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("impermeable"), Material.class)
    """
    Vanilla block tag denoting impermeable blocks which do not drip fluids.
    """
    UNDERWATER_BONEMEALS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("underwater_bonemeals"), Material.class)
    """
    Vanilla block tag denoting all underwater blocks which may be bonemealed.
    """
    CORAL_BLOCKS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("coral_blocks"), Material.class)
    """
    Vanilla block tag representing all coral blocks.
    """
    WALL_CORALS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("wall_corals"), Material.class)
    """
    Vanilla block tag representing all wall corals.
    """
    CORAL_PLANTS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("coral_plants"), Material.class)
    """
    Vanilla block tag representing all coral plants.
    """
    CORALS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("corals"), Material.class)
    """
    Vanilla block tag representing all coral.
    """
    BAMBOO_PLANTABLE_ON = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("bamboo_plantable_on"), Material.class)
    """
    Vanilla block tag denoting all blocks bamboo may be planted on.
    """
    STANDING_SIGNS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("standing_signs"), Material.class)
    """
    Vanilla block tag representing all standing signs.
    """
    WALL_SIGNS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("wall_signs"), Material.class)
    """
    Vanilla block tag representing all wall signs.
    """
    SIGNS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("signs"), Material.class)
    """
    Vanilla block tag representing all regular signs.
    """
    CEILING_HANGING_SIGNS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("ceiling_hanging_signs"), Material.class)
    """
    Vanilla block tag representing all ceiling signs.
    """
    WALL_HANGING_SIGNS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("wall_hanging_signs"), Material.class)
    """
    Vanilla block tag representing all wall hanging signs.
    """
    ALL_HANGING_SIGNS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("all_hanging_signs"), Material.class)
    """
    Vanilla block tag representing all hanging signs.
    """
    ALL_SIGNS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("all_signs"), Material.class)
    """
    Vanilla block tag representing all signs, regardless of type.
    """
    DRAGON_IMMUNE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("dragon_immune"), Material.class)
    """
    Vanilla block tag representing all blocks immune to dragons.
    """
    DRAGON_TRANSPARENT = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("dragon_transparent"), Material.class)
    """
    Vanilla block tag representing all blocks transparent to the ender
    dragon.
    """
    WITHER_IMMUNE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("wither_immune"), Material.class)
    """
    Vanilla block tag representing all blocks immune to withers.
    """
    WITHER_SUMMON_BASE_BLOCKS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("wither_summon_base_blocks"), Material.class)
    """
    Vanilla block tag representing all base blocks used for wither summoning.
    """
    BEEHIVES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("beehives"), Material.class)
    """
    Vanilla block tag representing all beehives.
    """
    CROPS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("crops"), Material.class)
    """
    Vanilla block tag representing all crops.
    """
    BEE_GROWABLES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("bee_growables"), Material.class)
    """
    Vanilla block tag representing all bee growables.
    """
    PORTALS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("portals"), Material.class)
    """
    Vanilla block tag representing all portals.
    """
    FIRE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("fire"), Material.class)
    """
    Vanilla block tag representing all fire blocks.
    """
    NYLIUM = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("nylium"), Material.class)
    """
    Vanilla block tag representing all nylium blocks.
    """
    WART_BLOCKS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("wart_blocks"), Material.class)
    """
    Vanilla block tag representing all wart blocks.
    """
    BEACON_BASE_BLOCKS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("beacon_base_blocks"), Material.class)
    """
    Vanilla block tag representing all beacon base blocks.
    """
    SOUL_SPEED_BLOCKS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("soul_speed_blocks"), Material.class)
    """
    Vanilla block tag representing all blocks affected by the soul speed
    enchantment.
    """
    WALL_POST_OVERRIDE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("wall_post_override"), Material.class)
    """
    Vanilla block tag representing all wall post overrides.
    """
    CLIMBABLE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("climbable"), Material.class)
    """
    Vanilla block tag representing all climbable blocks.
    """
    FALL_DAMAGE_RESETTING = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("fall_damage_resetting"), Material.class)
    """
    Vanilla block tag representing all blocks which reset fall damage.
    """
    SHULKER_BOXES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("shulker_boxes"), Material.class)
    """
    Vanilla block tag representing all shulker boxes.
    """
    HOGLIN_REPELLENTS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("hoglin_repellents"), Material.class)
    """
    Vanilla block tag representing all hoglin repellents.
    """
    SOUL_FIRE_BASE_BLOCKS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("soul_fire_base_blocks"), Material.class)
    """
    Vanilla block tag representing all soul fire base blocks.
    """
    STRIDER_WARM_BLOCKS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("strider_warm_blocks"), Material.class)
    """
    Vanilla block tag representing all warm strider blocks.
    """
    CAMPFIRES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("campfires"), Material.class)
    """
    Vanilla block tag representing all campfires.
    """
    GUARDED_BY_PIGLINS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("guarded_by_piglins"), Material.class)
    """
    Vanilla block tag representing all blocks guarded by piglins.
    """
    PREVENT_MOB_SPAWNING_INSIDE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("prevent_mob_spawning_inside"), Material.class)
    """
    Vanilla block tag representing all blocks that prevent inside mob
    spawning.
    """
    FENCE_GATES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("fence_gates"), Material.class)
    """
    Vanilla block tag representing all fence gates.
    """
    UNSTABLE_BOTTOM_CENTER = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("unstable_bottom_center"), Material.class)
    """
    Vanilla block tag representing all unstable bottom center blocks.
    """
    MUSHROOM_GROW_BLOCK = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("mushroom_grow_block"), Material.class)
    INFINIBURN_OVERWORLD = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("infiniburn_overworld"), Material.class)
    """
    Vanilla block tag representing all blocks that burn forever in the
    overworld.
    """
    INFINIBURN_NETHER = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("infiniburn_nether"), Material.class)
    """
    Vanilla block tag representing all blocks that burn forever in the
    nether.
    """
    INFINIBURN_END = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("infiniburn_end"), Material.class)
    """
    Vanilla block tag representing all blocks that burn forever in the end.
    """
    BASE_STONE_OVERWORLD = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("base_stone_overworld"), Material.class)
    """
    Vanilla block tag representing the overworld base material.
    """
    STONE_ORE_REPLACEABLES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("stone_ore_replaceables"), Material.class)
    """
    Vanilla block tag representing all blocks that may be replaced by ores.
    """
    DEEPSLATE_ORE_REPLACEABLES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("deepslate_ore_replaceables"), Material.class)
    """
    Vanilla block tag representing all blocks that may be replaced by
    deepslate ores.
    """
    BASE_STONE_NETHER = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("base_stone_nether"), Material.class)
    """
    Vanilla block tag representing the nether base material.
    """
    OVERWORLD_CARVER_REPLACEABLES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("overworld_carver_replaceables"), Material.class)
    """
    Vanilla block tag representing all blocks replaceable by the overworld
    carver.
    """
    NETHER_CARVER_REPLACEABLES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("nether_carver_replaceables"), Material.class)
    """
    Vanilla block tag representing all blocks replaceable by the nether
    carver.
    """
    CANDLE_CAKES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("candle_cakes"), Material.class)
    """
    Vanilla block tag representing all candle cakes.
    """
    CAULDRONS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("cauldrons"), Material.class)
    """
    Vanilla block tag representing all cauldrons.
    """
    CRYSTAL_SOUND_BLOCKS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("crystal_sound_blocks"), Material.class)
    """
    Vanilla block tag representing all blocks that make crystal sounds.
    """
    INSIDE_STEP_SOUND_BLOCKS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("inside_step_sound_blocks"), Material.class)
    """
    Vanilla block tag representing all blocks that play muffled step sounds.
    """
    COMBINATION_STEP_SOUND_BLOCKS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("combination_step_sound_blocks"), Material.class)
    """
    Vanilla block tag representing all blocks that play combination step sounds.
    """
    CAMEL_SAND_STEP_SOUND_BLOCKS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("camel_sand_step_sound_blocks"), Material.class)
    """
    Vanilla block tag representing all blocks that play step sounds with camels on sand.
    """
    OCCLUDES_VIBRATION_SIGNALS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("occludes_vibration_signals"), Material.class)
    """
    Vanilla block tag representing all blocks that block vibration signals.
    """
    DAMPENS_VIBRATIONS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("dampens_vibrations"), Material.class)
    """
    Vanilla block tag representing all blocks that dampen the propagation of
    vibration signals.
    """
    DRIPSTONE_REPLACEABLE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("dripstone_replaceable_blocks"), Material.class)
    """
    Vanilla block tag representing all blocks that are replaceable by
    dripstone.
    """
    CAVE_VINES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("cave_vines"), Material.class)
    """
    Vanilla block tag representing all cave vines.
    """
    MOSS_REPLACEABLE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("moss_replaceable"), Material.class)
    """
    Vanilla block tag representing all blocks replaceable by moss.
    """
    LUSH_GROUND_REPLACEABLE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("lush_ground_replaceable"), Material.class)
    """
    Vanilla block tag representing all blocks replaceable by lush ground.
    """
    AZALEA_ROOT_REPLACEABLE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("azalea_root_replaceable"), Material.class)
    """
    Vanilla block tag representing all blocks replaceable by azalea root.
    """
    SMALL_DRIPLEAF_PLACEABLE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("small_dripleaf_placeable"), Material.class)
    """
    Vanilla block tag representing all blocks which small dripleaf can be
    placed on.
    """
    BIG_DRIPLEAF_PLACEABLE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("big_dripleaf_placeable"), Material.class)
    """
    Vanilla block tag representing all blocks which big dripleaf can be
    placed on.
    """
    SNOW = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("snow"), Material.class)
    """
    Vanilla block tag representing all snow blocks.
    """
    MINEABLE_AXE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("mineable/axe"), Material.class)
    """
    Vanilla block tag representing all blocks mineable with an axe.
    """
    MINEABLE_HOE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("mineable/hoe"), Material.class)
    """
    Vanilla block tag representing all blocks mineable with a hoe.
    """
    MINEABLE_PICKAXE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("mineable/pickaxe"), Material.class)
    """
    Vanilla block tag representing all blocks mineable with a pickaxe.
    """
    MINEABLE_SHOVEL = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("mineable/shovel"), Material.class)
    """
    Vanilla block tag representing all blocks mineable with a shovel.
    """
    SWORD_EFFICIENT = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("sword_efficient"), Material.class)
    """
    Vanilla block tag representing all blocks that can be efficiently mined with a sword.
    """
    NEEDS_DIAMOND_TOOL = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("needs_diamond_tool"), Material.class)
    """
    Vanilla block tag representing all blocks which require a diamond tool.
    """
    NEEDS_IRON_TOOL = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("needs_iron_tool"), Material.class)
    """
    Vanilla block tag representing all blocks which require an iron tool.
    """
    NEEDS_STONE_TOOL = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("needs_stone_tool"), Material.class)
    """
    Vanilla block tag representing all blocks which require a stone tool.
    """
    INCORRECT_FOR_NETHERITE_TOOL = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("incorrect_for_netherite_tool"), Material.class)
    """
    Vanilla block tag representing all blocks which will not drop items with a netherite tool.
    """
    INCORRECT_FOR_DIAMOND_TOOL = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("incorrect_for_diamond_tool"), Material.class)
    """
    Vanilla block tag representing all blocks which will not drop items with a diamond tool.
    """
    INCORRECT_FOR_IRON_TOOL = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("incorrect_for_iron_tool"), Material.class)
    """
    Vanilla block tag representing all blocks which will not drop items with a iron tool.
    """
    INCORRECT_FOR_STONE_TOOL = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("incorrect_for_stone_tool"), Material.class)
    """
    Vanilla block tag representing all blocks which will not drop items with a stone tool.
    """
    INCORRECT_FOR_GOLD_TOOL = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("incorrect_for_gold_tool"), Material.class)
    """
    Vanilla block tag representing all blocks which will not drop items with a gold tool.
    """
    INCORRECT_FOR_WOODEN_TOOL = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("incorrect_for_wooden_tool"), Material.class)
    """
    Vanilla block tag representing all blocks which will not drop items with a wooden tool.
    """
    FEATURES_CANNOT_REPLACE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("features_cannot_replace"), Material.class)
    """
    Vanilla block tag representing all blocks which will not be replaced by
    world generation features.
    """
    LAVA_POOL_STONE_CANNOT_REPLACE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("lava_pool_stone_cannot_replace"), Material.class)
    """
    Vanilla block tag representing all blocks which lava pools will not
    replace.
    """
    GEODE_INVALID_BLOCKS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("geode_invalid_blocks"), Material.class)
    """
    Vanilla block tag representing all blocks which geodes will not spawn in.
    """
    FROG_PREFER_JUMP_TO = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("frog_prefer_jump_to"), Material.class)
    """
    Vanilla block tag representing all blocks which frogs prefer to jump to.
    """
    SCULK_REPLACEABLE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("sculk_replaceable"), Material.class)
    """
    Vanilla block tag representing all blocks which can be replaced by skulk.
    """
    SCULK_REPLACEABLE_WORLD_GEN = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("sculk_replaceable_world_gen"), Material.class)
    """
    Vanilla block tag representing all blocks which can be replaced by skulk
    during world generation.
    """
    ANCIENT_CITY_REPLACEABLE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("ancient_city_replaceable"), Material.class)
    """
    Vanilla block tag representing all blocks which can be replaced by
    ancient cities.
    """
    VIBRATION_RESONATORS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("vibration_resonators"), Material.class)
    """
    Vanilla block tag representing all blocks which resonate vibrations.
    """
    ANIMALS_SPAWNABLE_ON = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("animals_spawnable_on"), Material.class)
    """
    Vanilla block tag representing all blocks which animals will spawn on.
    """
    ARMADILLO_SPAWNABLE_ON = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("armadillo_spawnable_on"), Material.class)
    """
    Vanilla block tag representing all blocks which armadillos will spawn on.
    """
    AXOLOTLS_SPAWNABLE_ON = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("axolotls_spawnable_on"), Material.class)
    """
    Vanilla block tag representing all blocks which axolotls will spawn on.
    """
    GOATS_SPAWNABLE_ON = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("goats_spawnable_on"), Material.class)
    """
    Vanilla block tag representing all blocks which goats will spawn on.
    """
    MOOSHROOMS_SPAWNABLE_ON = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("mooshrooms_spawnable_on"), Material.class)
    """
    Vanilla block tag representing all blocks which mooshrooms will spawn on.
    """
    PARROTS_SPAWNABLE_ON = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("parrots_spawnable_on"), Material.class)
    """
    Vanilla block tag representing all blocks which parrots will spawn on.
    """
    POLAR_BEARS_SPAWNABLE_ON_ALTERNATE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("polar_bears_spawnable_on_alternate"), Material.class)
    """
    Vanilla block tag representing all blocks which polar bears will spawn
    on.
    """
    RABBITS_SPAWNABLE_ON = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("rabbits_spawnable_on"), Material.class)
    """
    Vanilla block tag representing all blocks which rabbits will spawn on.
    """
    FOXES_SPAWNABLE_ON = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("foxes_spawnable_on"), Material.class)
    """
    Vanilla block tag representing all blocks which foxes will spawn on.
    """
    WOLVES_SPAWNABLE_ON = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("wolves_spawnable_on"), Material.class)
    """
    Vanilla block tag representing all blocks which wolves will spawn on.
    """
    FROGS_SPAWNABLE_ON = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("frogs_spawnable_on"), Material.class)
    """
    Vanilla block tag representing all blocks which frogs will spawn on.
    """
    BATS_SPAWNABLE_ON = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("bats_spawnable_on"), Material.class)
    """
    Vanilla block tag representing all blocks which bats will spawn on.
    """
    AZALEA_GROWS_ON = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("azalea_grows_on"), Material.class)
    """
    Vanilla block tag representing all blocks which azaleas will grow on.
    """
    CONVERTABLE_TO_MUD = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("convertable_to_mud"), Material.class)
    """
    Vanilla block tag representing all blocks which may be converted to mud.
    """
    MANGROVE_LOGS_CAN_GROW_THROUGH = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("mangrove_logs_can_grow_through"), Material.class)
    """
    Vanilla block tag representing all blocks which mangrove logs can grow
    through.
    """
    MANGROVE_ROOTS_CAN_GROW_THROUGH = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("mangrove_roots_can_grow_through"), Material.class)
    """
    Vanilla block tag representing all blocks which mangrove roots can grow
    through.
    """
    DEAD_BUSH_MAY_PLACE_ON = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("dead_bush_may_place_on"), Material.class)
    """
    Vanilla block tag representing all blocks which dead bushes may be placed
    on.
    """
    SNAPS_GOAT_HORN = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("snaps_goat_horn"), Material.class)
    """
    Vanilla block tag representing all blocks which snap dropped goat horns.
    """
    REPLACEABLE_BY_TREES = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("replaceable_by_trees"), Material.class)
    """
    Vanilla block tag representing all blocks replaceable by growing trees.
    """
    SNOW_LAYER_CANNOT_SURVIVE_ON = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("snow_layer_cannot_survive_on"), Material.class)
    """
    Vanilla block tag representing blocks which snow cannot survive on.
    """
    SNOW_LAYER_CAN_SURVIVE_ON = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("snow_layer_can_survive_on"), Material.class)
    """
    Vanilla block tag representing blocks which snow can survive on.
    """
    INVALID_SPAWN_INSIDE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("invalid_spawn_inside"), Material.class)
    """
    Vanilla block tag representing blocks which cannot be dismounted into.
    """
    SNIFFER_DIGGABLE_BLOCK = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("sniffer_diggable_block"), Material.class)
    """
    Vanilla block tag representing blocks which can be dug by sniffers.
    """
    SNIFFER_EGG_HATCH_BOOST = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("sniffer_egg_hatch_boost"), Material.class)
    """
    Vanilla block tag representing all blocks which booster sniffer egg hatching.
    """
    TRAIL_RUINS_REPLACEABLE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("trail_ruins_replaceable"), Material.class)
    """
    Vanilla block tag representing all blocks which can be replaced by trail ruins.
    """
    REPLACEABLE = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("replaceable"), Material.class)
    """
    Vanilla block tag representing all blocks which are replaceable.
    """
    ENCHANTMENT_POWER_PROVIDER = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("enchantment_power_provider"), Material.class)
    """
    Vanilla block tag representing all blocks which provide enchantment power.
    """
    ENCHANTMENT_POWER_TRANSMITTER = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("enchantment_power_transmitter"), Material.class)
    """
    Vanilla block tag representing all blocks which transmit enchantment power.
    """
    MAINTAINS_FARMLAND = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("maintains_farmland"), Material.class)
    """
    Vanilla block tag representing all blocks which do not destroy farmland when placed.
    """
    BLOCKS_WIND_CHARGE_EXPLOSIONS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("blocks_wind_charge_explosions"), Material.class)
    """
    Vanilla block tag representing all blocks which block wind charge explosions.
    """
    DOES_NOT_BLOCK_HOPPERS = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("does_not_block_hoppers"), Material.class)
    """
    Vanilla block tag representing solid blocks which do not block hopper operation.
    """
    AIR = Bukkit.getTag(REGISTRY_BLOCKS, NamespacedKey.minecraft("air"), Material.class)
    """
    Vanilla block tag representing all blocks that resemble air.
    """
    REGISTRY_ITEMS = "items"
    """
    Key for the built in item registry.
    """
    ITEMS_PIGLIN_LOVED = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("piglin_loved"), Material.class)
    """
    Vanilla item tag representing all items loved by piglins.
    """
    IGNORED_BY_PIGLIN_BABIES = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("ignored_by_piglin_babies"), Material.class)
    """
    Vanilla item tag representing all items ignored by piglin babies.
    """
    ITEMS_PIGLIN_SAFE_ARMOR = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("piglin_safe_armor"), Material.class)
    """
    Vanilla item tag representing all items which will prevent piglins from being angered.
    """
    ITEMS_DUPLICATES_ALLAYS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("duplicates_allays"), Material.class)
    """
    Vanilla item tag representing all items which can be used to duplicate Allays when they are dancing.
    """
    ITEMS_BREWING_FUEL = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("brewing_fuel"), Material.class)
    """
    Vanilla item tag representing all brewing stand fuel items.
    """
    ITEMS_MEAT = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("meat"), Material.class)
    """
    Vanilla item tag representing all meat.
    """
    ITEMS_SNIFFER_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("sniffer_food"), Material.class)
    """
    Vanilla item tag representing all sniffer food.
    """
    ITEMS_PIGLIN_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("piglin_food"), Material.class)
    """
    Vanilla item tag representing all piglin food.
    """
    PIGLIN_FOOD = ITEMS_PIGLIN_FOOD
    """
    Vanilla item tag representing all piglin food.

    Deprecated
    - use .ITEMS_PIGLIN_FOOD
    """
    ITEMS_FOX_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("fox_food"), Material.class)
    """
    Vanilla item tag representing all fox food.
    """
    FOX_FOOD = ITEMS_FOX_FOOD
    """
    Vanilla item tag representing all fox food.

    Deprecated
    - use .ITEMS_FOX_FOOD
    """
    ITEMS_COW_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("cow_food"), Material.class)
    """
    Vanilla item tag representing all cow food.
    """
    ITEMS_GOAT_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("goat_food"), Material.class)
    """
    Vanilla item tag representing all goat food.
    """
    ITEMS_SHEEP_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("sheep_food"), Material.class)
    """
    Vanilla item tag representing all sheep food.
    """
    ITEMS_WOLF_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("wolf_food"), Material.class)
    """
    Vanilla item tag representing all wolf food.
    """
    ITEMS_CAT_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("cat_food"), Material.class)
    """
    Vanilla item tag representing all cat food.
    """
    ITEMS_HORSE_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("horse_food"), Material.class)
    """
    Vanilla item tag representing all horse food.
    """
    ITEMS_HORSE_TEMPT_ITEMS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("horse_tempt_items"), Material.class)
    """
    Vanilla item tag representing all horse tempt items.
    """
    ITEMS_CAMEL_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("camel_food"), Material.class)
    """
    Vanilla item tag representing all camel food.
    """
    ITEMS_ARMADILLO_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("armadillo_food"), Material.class)
    """
    Vanilla item tag representing all armadillo food.
    """
    ITEMS_BEE_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("bee_food"), Material.class)
    """
    Vanilla item tag representing all bee food.
    """
    ITEMS_CHICKEN_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("chicken_food"), Material.class)
    """
    Vanilla item tag representing all chicken food.
    """
    ITEMS_FROG_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("frog_food"), Material.class)
    """
    Vanilla item tag representing all frog food.
    """
    ITEMS_HOGLIN_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("hoglin_food"), Material.class)
    """
    Vanilla item tag representing all hoglin food.
    """
    ITEMS_LLAMA_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("llama_food"), Material.class)
    """
    Vanilla item tag representing all llama food.
    """
    ITEMS_LLAMA_TEMPT_ITEMS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("llama_tempt_items"), Material.class)
    """
    Vanilla item tag representing all llama tempt items.
    """
    ITEMS_OCELOT_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("ocelot_food"), Material.class)
    """
    Vanilla item tag representing all ocelot food.
    """
    ITEMS_PANDA_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("panda_food"), Material.class)
    """
    Vanilla item tag representing all panda food.
    """
    ITEMS_PANDA_EATS_FROM_GROUND = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("panda_eats_from_ground"), Material.class)
    """
    Vanilla item tag representing all items that a panda will pick up and eat from the ground.
    """
    ITEMS_PIG_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("pig_food"), Material.class)
    """
    Vanilla item tag representing all pig food.
    """
    ITEMS_RABBIT_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("rabbit_food"), Material.class)
    """
    Vanilla item tag representing all rabbit food.
    """
    ITEMS_STRIDER_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("strider_food"), Material.class)
    """
    Vanilla item tag representing all strider food.
    """
    ITEMS_STRIDER_TEMPT_ITEMS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("strider_tempt_items"), Material.class)
    """
    Vanilla item tag representing all strider tempt items.
    """
    ITEMS_TURTLE_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("turtle_food"), Material.class)
    """
    Vanilla item tag representing all turtle food.
    """
    ITEMS_PARROT_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("parrot_food"), Material.class)
    """
    Vanilla item tag representing all parrot food.
    """
    ITEMS_PARROT_POISONOUS_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("parrot_poisonous_food"), Material.class)
    """
    Vanilla item tag representing all parrot poisonous food.
    """
    ITEMS_AXOLOTL_FOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("axolotl_food"), Material.class)
    """
    Vanilla item tag representing all axolotl food.
    """
    ITEMS_BANNERS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("banners"), Material.class)
    """
    Vanilla item tag representing all banner items.
    """
    ITEMS_NON_FLAMMABLE_WOOD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("non_flammable_wood"), Material.class)
    """
    Vanilla item tag representing all non flammable wood items.
    """
    ITEMS_BOATS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("boats"), Material.class)
    """
    Vanilla item tag representing all boat items.
    """
    ITEMS_CHEST_BOATS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("chest_boats"), Material.class)
    """
    Vanilla item tag representing all chest boat items.
    """
    ITEMS_FISHES = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("fishes"), Material.class)
    """
    Vanilla item tag representing all fish items.
    """
    ITEMS_CREEPER_DROP_MUSIC_DISCS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("creeper_drop_music_discs"), Material.class)
    """
    Vanilla item tag representing all music disc items dropped by creepers.
    """
    ITEMS_COALS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("coals"), Material.class)
    """
    Vanilla item tag representing all coal items.
    """
    ITEMS_ARROWS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("arrows"), Material.class)
    """
    Vanilla item tag representing all arrow items.
    """
    ITEMS_LECTERN_BOOKS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("lectern_books"), Material.class)
    """
    Vanilla item tag representing all books that may be placed on lecterns.
    """
    ITEMS_BOOKSHELF_BOOKS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("bookshelf_books"), Material.class)
    """
    Vanilla item tag representing all books that may be placed on bookshelves.
    """
    ITEMS_BEACON_PAYMENT_ITEMS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("beacon_payment_items"), Material.class)
    """
    Vanilla item tag representing all items that may be placed in beacons.
    """
    ITEMS_WOODEN_TOOL_MATERIALS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("wooden_tool_materials"), Material.class)
    """
    Vanilla item tag representing all wooden tool materials.
    """
    ITEMS_STONE_TOOL_MATERIALS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("stone_tool_materials"), Material.class)
    """
    Vanilla item tag representing all stone tool materials.
    """
    ITEMS_IRON_TOOL_MATERIALS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("iron_tool_materials"), Material.class)
    """
    Vanilla item tag representing all iron tool materials.
    """
    ITEMS_GOLD_TOOL_MATERIALS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("gold_tool_materials"), Material.class)
    """
    Vanilla item tag representing all gold tool materials.
    """
    ITEMS_DIAMOND_TOOL_MATERIALS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("diamond_tool_materials"), Material.class)
    """
    Vanilla item tag representing all diamond tool materials.
    """
    ITEMS_NETHERITE_TOOL_MATERIALS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("netherite_tool_materials"), Material.class)
    """
    Vanilla item tag representing all netherite tool materials.
    """
    ITEMS_REPAIRS_LEATHER_ARMOR = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("repairs_leather_armor"), Material.class)
    """
    Vanilla item tag representing all items which repair leather armor.
    """
    ITEMS_REPAIRS_CHAIN_ARMOR = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("repairs_chain_armor"), Material.class)
    """
    Vanilla item tag representing all items which repair chain armor.
    """
    ITEMS_REPAIRS_IRON_ARMOR = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("repairs_iron_armor"), Material.class)
    """
    Vanilla item tag representing all items which repair iron armor.
    """
    ITEMS_REPAIRS_GOLD_ARMOR = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("repairs_gold_armor"), Material.class)
    """
    Vanilla item tag representing all items which repair gold armor.
    """
    ITEMS_REPAIRS_DIAMOND_ARMOR = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("repairs_diamond_armor"), Material.class)
    """
    Vanilla item tag representing all items which repair diamond armor.
    """
    ITEMS_REPAIRS_NETHERITE_ARMOR = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("repairs_netherite_armor"), Material.class)
    """
    Vanilla item tag representing all items which repair netherite armor.
    """
    ITEMS_REPAIRS_TURTLE_HELMET = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("repairs_turtle_helmet"), Material.class)
    """
    Vanilla item tag representing all items which repair turtle helmets.
    """
    ITEMS_REPAIRS_WOLF_ARMOR = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("repairs_wolf_armor"), Material.class)
    """
    Vanilla item tag representing all items which repair wolf armor.
    """
    ITEMS_FURNACE_MATERIALS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("furnace_materials"), Material.class)
    """
    Vanilla item tag representing all furnace materials.
    """
    ITEMS_COMPASSES = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("compasses"), Material.class)
    """
    Vanilla item tag representing all compasses.
    """
    ITEMS_HANGING_SIGNS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("hanging_signs"), Material.class)
    """
    Vanilla item tag representing all hanging signs.
    """
    ITEMS_CREEPER_IGNITERS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("creeper_igniters"), Material.class)
    """
    Vanilla item tag representing all items which will ignite creepers when
    interacted with.
    """
    ITEMS_NOTE_BLOCK_TOP_INSTRUMENTS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("noteblock_top_instruments"), Material.class)
    """
    Vanilla item tag representing all items which modify note block sounds when placed on top.
    """
    ITEMS_FOOT_ARMOR = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("foot_armor"), Material.class)
    """
    Vanilla item tag representing all foot armor.
    """
    ITEMS_LEG_ARMOR = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("leg_armor"), Material.class)
    """
    Vanilla item tag representing all leg armor.
    """
    ITEMS_CHEST_ARMOR = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("chest_armor"), Material.class)
    """
    Vanilla item tag representing all chest armor.
    """
    ITEMS_HEAD_ARMOR = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("head_armor"), Material.class)
    """
    Vanilla item tag representing all head armor.
    """
    ITEMS_SKULLS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("skulls"), Material.class)
    """
    Vanilla item tag representing all skulls.
    """
    ITEMS_TRIMMABLE_ARMOR = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("trimmable_armor"), Material.class)
    """
    Vanilla item tag representing all trimmable armor items.
    """
    ITEMS_TRIM_MATERIALS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("trim_materials"), Material.class)
    """
    Vanilla item tag representing all materials which can be used for trimming armor.
    """
    ITEMS_DECORATED_POT_SHERDS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("decorated_pot_sherds"), Material.class)
    """
    Vanilla item tag representing all decorated pot sherds.
    """
    ITEMS_DECORATED_POT_INGREDIENTS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("decorated_pot_ingredients"), Material.class)
    """
    Vanilla item tag representing all decorated pot ingredients.
    """
    ITEMS_SWORDS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("swords"), Material.class)
    """
    Vanilla item tag representing all swords.
    """
    ITEMS_AXES = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("axes"), Material.class)
    """
    Vanilla item tag representing all axes.
    """
    ITEMS_HOES = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("hoes"), Material.class)
    """
    Vanilla item tag representing all hoes.
    """
    ITEMS_PICKAXES = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("pickaxes"), Material.class)
    """
    Vanilla item tag representing all pickaxes.
    """
    ITEMS_SHOVELS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("shovels"), Material.class)
    """
    Vanilla item tag representing all shovels.
    """
    ITEMS_BREAKS_DECORATED_POTS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("breaks_decorated_pots"), Material.class)
    """
    Vanilla item tag representing all items which break decorated pots.
    """
    ITEMS_TOOLS = ITEMS_BREAKS_DECORATED_POTS
    """
    Vanilla item tag representing all tools.

    Deprecated
    - removed in Minecraft 1.20.5. Do not use. Will be removed at a later date. Until then,
    this constant now acts as a reference to .ITEMS_BREAKS_DECORATED_POTS which largely shares
    the same contents of the old "minecraft:tools" tag.
    """
    ITEMS_VILLAGER_PLANTABLE_SEEDS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("villager_plantable_seeds"), Material.class)
    """
    Vanilla item tag representing all seeds plantable by villagers.
    """
    ITEMS_VILLAGER_PICKS_UP = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("villager_picks_up"), Material.class)
    """
    Vanilla item tag representing all items which villagers pick up.
    """
    ITEMS_DYEABLE = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("dyeable"), Material.class)
    """
    Vanilla item tag representing all dyeable items.
    """
    ITEMS_FURNACE_MINECART_FUEL = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("furnace_minecart_fuel"), Material.class)
    """
    Vanilla item tag representing all furnace minecart fuel.
    """
    ITEMS_BUNDLES = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("bundles"), Material.class)
    """
    Vanilla item tag representing all bundle items.
    """
    ITEMS_SKELETON_PREFERRED_WEAPONS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("skeleton_preferred_weapons"), Material.class)
    """
    Vanilla item tag representing all skeleton preferred weapons.
    """
    ITEMS_DROWNED_PREFERRED_WEAPONS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("drowned_preferred_weapons"), Material.class)
    """
    Vanilla item tag representing all drowned preferred weapons.
    """
    ITEMS_PIGLIN_PREFERRED_WEAPONS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("piglin_preferred_weapons"), Material.class)
    """
    Vanilla item tag representing all piglin preferred weapons.
    """
    ITEMS_PILLAGER_PREFERRED_WEAPONS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("pillager_preferred_weapons"), Material.class)
    """
    Vanilla item tag representing all pillager preferred weapons.
    """
    ITEMS_WITHER_SKELETON_DISLIKED_WEAPONS = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("wither_skeleton_disliked_weapons"), Material.class)
    """
    Vanilla item tag representing all wither skeleton disliked weapons.
    """
    ITEMS_ENCHANTABLE_FOOT_ARMOR = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("enchantable/foot_armor"), Material.class)
    """
    Vanilla item tag representing all enchantable foot armor.
    """
    ITEMS_ENCHANTABLE_LEG_ARMOR = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("enchantable/leg_armor"), Material.class)
    """
    Vanilla item tag representing all enchantable leg armor.
    """
    ITEMS_ENCHANTABLE_CHEST_ARMOR = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("enchantable/chest_armor"), Material.class)
    """
    Vanilla item tag representing all enchantable chest armor.
    """
    ITEMS_ENCHANTABLE_HEAD_ARMOR = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("enchantable/head_armor"), Material.class)
    """
    Vanilla item tag representing all enchantable head armor.
    """
    ITEMS_ENCHANTABLE_ARMOR = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("enchantable/armor"), Material.class)
    """
    Vanilla item tag representing all enchantable armor.
    """
    ITEMS_ENCHANTABLE_SWORD = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("enchantable/sword"), Material.class)
    """
    Vanilla item tag representing all enchantable swords.
    """
    ITEMS_ENCHANTABLE_FIRE_ASPECT = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("enchantable/fire_aspect"), Material.class)
    """
    Vanilla item tag representing all items enchantable with the fire aspect enchantment.
    """
    ITEMS_ENCHANTABLE_SHARP_WEAPON = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("enchantable/sharp_weapon"), Material.class)
    """
    Vanilla item tag representing all items enchantable with the sharpness enchantment.
    """
    ITEMS_ENCHANTABLE_WEAPON = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("enchantable/weapon"), Material.class)
    """
    Vanilla item tag representing all enchantable weapons.
    """
    ITEMS_ENCHANTABLE_MINING = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("enchantable/mining"), Material.class)
    """
    Vanilla item tag representing all enchantable mining tools.
    """
    ITEMS_ENCHANTABLE_MINING_LOOT = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("enchantable/mining_loot"), Material.class)
    """
    Vanilla item tag representing all items enchantable with the mining_loot enchantment.
    """
    ITEMS_ENCHANTABLE_FISHING = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("enchantable/fishing"), Material.class)
    """
    Vanilla item tag representing all items enchantable with fishing enchantments.
    """
    ITEMS_ENCHANTABLE_TRIDENT = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("enchantable/trident"), Material.class)
    """
    Vanilla item tag representing all items enchantable with trident enchantments.
    """
    ITEMS_ENCHANTABLE_DURABILITY = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("enchantable/durability"), Material.class)
    """
    Vanilla item tag representing all items enchantable with durability enchantments.
    """
    ITEMS_ENCHANTABLE_BOW = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("enchantable/bow"), Material.class)
    """
    Vanilla item tag representing all items enchantable with bow enchantments.
    """
    ITEMS_ENCHANTABLE_EQUIPPABLE = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("enchantable/equippable"), Material.class)
    """
    Vanilla item tag representing all items enchantable with the binding enchantment.
    """
    ITEMS_ENCHANTABLE_CROSSBOW = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("enchantable/crossbow"), Material.class)
    """
    Vanilla item tag representing all items enchantable with crossbow enchantments.
    """
    ITEMS_ENCHANTABLE_VANISHING = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("enchantable/vanishing"), Material.class)
    """
    Vanilla item tag representing all items enchantable with the vanishing enchantment.
    """
    ITEMS_ENCHANTABLE_MACE = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("enchantable/mace"), Material.class)
    """
    Vanilla item tag representing all items enchantable with mace enchantments.
    """
    ITEMS_MAP_INVISIBILITY_EQUIPMENT = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("map_invisibility_equipment"), Material.class)
    """
    Vanilla item tag representing all items which when equipped will hide the entity from maps.
    """
    ITEMS_GAZE_DISGUISE_EQUIPMENT = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("gaze_disguise_equipment"), Material.class)
    """
    Vanilla item tag representing all items which disguise the wearer's gaze from other entities.
    """
    FREEZE_IMMUNE_WEARABLES = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("freeze_immune_wearables"), Material.class)
    """
    Vanilla item tag representing all items that confer freeze immunity on
    the wearer.
    """
    AXOLOTL_TEMPT_ITEMS = ITEMS_AXOLOTL_FOOD
    """
    Vanilla item tag representing all items which tempt axolotls.

    Deprecated
    - use .ITEMS_AXOLOTL_FOOD
    """
    CLUSTER_MAX_HARVESTABLES = Bukkit.getTag(REGISTRY_ITEMS, NamespacedKey.minecraft("cluster_max_harvestables"), Material.class)
    """
    Vanilla item tag representing all items which are preferred for
    harvesting clusters (unused).
    """
    REGISTRY_FLUIDS = "fluids"
    """
    Key for the built in fluid registry.
    """
    FLUIDS_LAVA = Bukkit.getTag(REGISTRY_FLUIDS, NamespacedKey.minecraft("lava"), Fluid.class)
    """
    Vanilla fluid tag representing lava and flowing lava.
    """
    FLUIDS_WATER = Bukkit.getTag(REGISTRY_FLUIDS, NamespacedKey.minecraft("water"), Fluid.class)
    """
    Vanilla fluid tag representing water and flowing water.
    """
    REGISTRY_ENTITY_TYPES = "entity_types"
    """
    Key for the built in entity registry.
    """
    ENTITY_TYPES_SKELETONS = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("skeletons"), EntityType.class)
    """
    Vanilla tag representing skeletons.
    """
    ENTITY_TYPES_RAIDERS = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("raiders"), EntityType.class)
    """
    Vanilla tag representing raiders.
    """
    ENTITY_TYPES_BEEHIVE_INHABITORS = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("beehive_inhabitors"), EntityType.class)
    """
    Vanilla tag representing entities which can live in beehives.
    """
    ENTITY_TYPES_ARROWS = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("arrows"), EntityType.class)
    """
    Vanilla tag representing arrows.
    """
    ENTITY_TYPES_IMPACT_PROJECTILES = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("impact_projectiles"), EntityType.class)
    """
    Vanilla tag representing projectiles.
    """
    ENTITY_TYPES_POWDER_SNOW_WALKABLE_MOBS = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("powder_snow_walkable_mobs"), EntityType.class)
    """
    Vanilla tag representing mobs which can walk on powder snow.
    """
    ENTITY_TYPES_AXOLOTL_ALWAYS_HOSTILES = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("axolotl_always_hostiles"), EntityType.class)
    """
    Vanilla tag representing which entities axolotls are always hostile to.
    """
    ENTITY_TYPES_AXOLOTL_HUNT_TARGETS = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("axolotl_hunt_targets"), EntityType.class)
    """
    Vanilla tag representing axolotl targets.
    """
    ENTITY_TYPES_FREEZE_IMMUNE_ENTITY_TYPES = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("freeze_immune_entity_types"), EntityType.class)
    """
    Vanilla tag representing entities immune from freezing.
    """
    ENTITY_TYPES_FREEZE_HURTS_EXTRA_TYPES = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("freeze_hurts_extra_types"), EntityType.class)
    """
    Vanilla tag representing entities extra susceptible to freezing.
    """
    ENTITY_TYPES_FROG_FOOD = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("frog_food"), EntityType.class)
    """
    Vanilla tag representing entities which can be eaten by frogs.
    """
    ENTITY_TYPES_FALL_DAMAGE_IMMUNE = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("fall_damage_immune"), EntityType.class)
    """
    Vanilla tag representing entities which are immune from fall damage.
    """
    ENTITY_TYPES_DISMOUNTS_UNDERWATER = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("dismounts_underwater"), EntityType.class)
    """
    Vanilla tag representing entities which are dismounted when underwater.
    """
    ENTITY_TYPES_NON_CONTROLLING_RIDER = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("non_controlling_rider"), EntityType.class)
    """
    Vanilla tag representing entities which are not controlled by their mount.
    """
    ENTITY_TYPES_DEFLECTS_PROJECTILES = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("deflects_projectiles"), EntityType.class)
    """
    Vanilla tag representing entities which deflect projectiles.
    """
    ENTITY_TYPES_DEFLECTS_ARROWS = ENTITY_TYPES_DEFLECTS_PROJECTILES
    """
    Vanilla tag representing entities which deflect arrows.

    Deprecated
    - use .ENTITY_TYPES_DEFLECTS_PROJECTILES
    """
    ENTITY_TYPES_CAN_TURN_IN_BOATS = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("can_turn_in_boats"), EntityType.class)
    """
    Vanilla tag representing entities which can turn in boats.
    """
    ENTITY_TYPES_ILLAGER = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("illager"), EntityType.class)
    """
    Vanilla tag representing all entities sensitive to illager enchantments.
    """
    ENTITY_TYPES_AQUATIC = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("aquatic"), EntityType.class)
    """
    Vanilla tag representing all entities sensitive to aquatic enchantments..
    """
    ENTITY_TYPES_ARTHROPOD = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("arthropod"), EntityType.class)
    """
    Vanilla tag representing all entities sensitive to arthropod enchantments..
    """
    ENTITY_TYPES_IGNORES_POISON_AND_REGEN = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("ignores_poison_and_regen"), EntityType.class)
    """
    Vanilla tag representing all entities which ignores poison and regeneration effects.
    """
    ENTITY_TYPES_INVERTED_HEALING_AND_HARM = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("inverted_healing_and_harm"), EntityType.class)
    """
    Vanilla tag representing all entities which are sensitive to inverted healing and harm potion effects.
    """
    ENTITY_TYPES_WITHER_FRIENDS = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("wither_friends"), EntityType.class)
    """
    Vanilla tag representing all entities which are friendly with withers.
    """
    ENTITY_TYPES_ILLAGER_FRIENDS = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("illager_friends"), EntityType.class)
    """
    Vanilla tag representing all entities which are friendly with illagers.
    """
    ENTITY_TYPES_NOT_SCARY_FOR_PUFFERFISH = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("not_scary_for_pufferfish"), EntityType.class)
    """
    Vanilla tag representing all entities which are not scary for pufferfish.
    """
    ENTITY_TYPES_SENSITIVE_TO_IMPALING = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("sensitive_to_impaling"), EntityType.class)
    """
    Vanilla tag representing all entities which are sensitive to impaling.
    """
    ENTITY_TYPES_SENSITIVE_TO_BANE_OF_ARTHROPODS = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("sensitive_to_bane_of_arthropods"), EntityType.class)
    """
    Vanilla tag representing all entities which are sensitive to the bane_of_arthropods enchantment.
    """
    ENTITY_TYPES_SENSITIVE_TO_SMITE = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("sensitive_to_smite"), EntityType.class)
    """
    Vanilla tag representing all entities which are sensitive to the smite enchantment.
    """
    ENTITY_TYPES_NO_ANGER_FROM_WIND_CHARGE = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("no_anger_from_wind_charge"), EntityType.class)
    """
    Vanilla tag representing all entities which do not receive anger from wind charges.
    """
    ENTITY_TYPES_IMMUNE_TO_OOZING = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("immune_to_oozing"), EntityType.class)
    """
    Vanilla tag representing all entities which are immune from the oozing effect.
    """
    ENTITY_TYPES_IMMUNE_TO_INFESTED = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("immune_to_infested"), EntityType.class)
    """
    Vanilla tag representing all entities which are immune from the infested effect.
    """
    ENTITY_TYPES_REDIRECTABLE_PROJECTILE = Bukkit.getTag(REGISTRY_ENTITY_TYPES, NamespacedKey.minecraft("redirectable_projectile"), EntityType.class)
    """
    Vanilla tag representing all projectiles which can be punched back.
    """


    def isTagged(self, item: "T") -> bool:
        """
        Returns whether or not this tag has an entry for the specified item.

        Arguments
        - item: to check

        Returns
        - if it is tagged
        """
        ...


    def getValues(self) -> set["T"]:
        """
        Gets an immutable set of all tagged items.

        Returns
        - set of tagged items
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.HorseJumpEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import AbstractHorse
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class HorseJumpEvent(EntityEvent, Cancellable):
    """
    Called when a horse jumps.
    """

    def __init__(self, horse: "AbstractHorse", power: float):
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        """
        Deprecated
        - horse jumping was moved client side.
        """
        ...


    def getEntity(self) -> "AbstractHorse":
        ...


    def getPower(self) -> float:
        """
        Gets the power of the jump.
        
        Power is a value that defines how much of the horse's jump strength
        should be used for the jump. Power is effectively multiplied times
        the horse's jump strength to determine how high the jump is; 0
        represents no jump strength while 1 represents full jump strength.
        Setting power to a value above 1 will use additional jump strength
        that the horse does not usually have.
        
        Power does not affect how high the horse is capable of jumping, only
        how much of its jumping capability will be used in this jump. To set
        the horse's overall jump strength, see AbstractHorse.setJumpStrength(double).

        Returns
        - jump strength
        """
        ...


    def setPower(self, power: float) -> None:
        """
        Sets the power of the jump.
        
        Jump power can be set to a value above 1.0 which will increase the
        strength of this jump above the horse's actual jump strength.
        
        Setting the jump power to 0 will result in the jump animation still
        playing, but the horse not leaving the ground. Only canceling this
        event will result in no jump animation at all.

        Arguments
        - power: power of the jump

        Deprecated
        - horse jumping was moved client side.
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



from .AsyncStructureGenerateEvent import AsyncStructureGenerateEvent
from .GenericGameEvent import GenericGameEvent
from .WorldInitEvent import WorldInitEvent
from .ChunkUnloadEvent import ChunkUnloadEvent
from .WorldLoadEvent import WorldLoadEvent
from .ChunkLoadEvent import ChunkLoadEvent
from .AsyncStructureSpawnEvent import AsyncStructureSpawnEvent
from .WorldSaveEvent import WorldSaveEvent
from .LootGenerateEvent import LootGenerateEvent
from .SpawnChangeEvent import SpawnChangeEvent
from .StructureGrowEvent import StructureGrowEvent
from .PortalCreateEvent import PortalCreateEvent
from .EntitiesLoadEvent import EntitiesLoadEvent
from .ChunkPopulateEvent import ChunkPopulateEvent
from .WorldUnloadEvent import WorldUnloadEvent
from .WorldEvent import WorldEvent
from .EntitiesUnloadEvent import EntitiesUnloadEvent
from .TimeSkipEvent import TimeSkipEvent
from .ChunkEvent import ChunkEvent


"""
Python module generated from Java source file org.bukkit.material.Lever

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.block import BlockFace
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class Lever(SimpleAttachableMaterialData, Redstone):
    """
    Represents a lever

    Deprecated
    - all usage of MaterialData is deprecated and subject to removal.
    Use org.bukkit.block.data.BlockData.
    """

    def __init__(self):
        ...


    def __init__(self, type: "Material"):
        ...


    def __init__(self, type: "Material", data: int):
        """
        Arguments
        - type: the type
        - data: the raw data value

        Deprecated
        - Magic value
        """
        ...


    def isPowered(self) -> bool:
        """
        Gets the current state of this Material, indicating if it's powered or
        unpowered

        Returns
        - True if powered, otherwise False
        """
        ...


    def setPowered(self, isPowered: bool) -> None:
        """
        Set this lever to be powered or not.

        Arguments
        - isPowered: whether the lever should be powered or not
        """
        ...


    def getAttachedFace(self) -> "BlockFace":
        """
        Gets the face that this block is attached on

        Returns
        - BlockFace attached to
        """
        ...


    def setFacingDirection(self, face: "BlockFace") -> None:
        """
        Sets the direction this lever is pointing in
        """
        ...


    def toString(self) -> str:
        ...


    def clone(self) -> "Lever":
        ...



"""
Python module generated from Java source file com.google.common.collect.MapMaker

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.base import Ascii
from com.google.common.base import Equivalence
from com.google.common.base import MoreObjects
from com.google.common.collect import *
from com.google.common.collect.MapMakerInternalMap import Strength
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.lang.ref import WeakReference
from java.util import ConcurrentModificationException
from java.util.concurrent import ConcurrentHashMap
from java.util.concurrent import ConcurrentMap
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class MapMaker:
    """
    A builder of ConcurrentMap instances that can have keys or values automatically wrapped
    in WeakReference weak references.
    
    Usage example:
    
    ````ConcurrentMap<Request, Stopwatch> timers = new MapMaker()
        .concurrencyLevel(4)
        .weakKeys()
        .makeMap();````
    
    These features are all optional; `new MapMaker().makeMap()` returns a valid concurrent
    map that behaves similarly to a ConcurrentHashMap.
    
    The returned map is implemented as a hash table with similar performance characteristics to
    ConcurrentHashMap. It supports all optional operations of the `ConcurrentMap`
    interface. It does not permit null keys or values.
    
    **Note:** by default, the returned map uses equality comparisons (the Object.equals
    equals method) to determine equality for keys or values. However, if .weakKeys was
    specified, the map uses identity (`==`) comparisons instead for keys. Likewise, if .weakValues was specified, the map uses identity comparisons for values.
    
    The view collections of the returned map have *weakly consistent iterators*. This means
    that they are safe for concurrent use, but if other threads modify the map after the iterator is
    created, it is undefined which of these changes, if any, are reflected in that iterator. These
    iterators never throw ConcurrentModificationException.
    
    If .weakKeys or .weakValues are requested, it is possible for a key or value
    present in the map to be reclaimed by the garbage collector. Entries with reclaimed keys or
    values may be removed from the map on each map modification or on occasional map accesses; such
    entries may be counted by Map.size, but will never be visible to read or write
    operations. A partially-reclaimed entry is never exposed to the user. Any Map.Entry
    instance retrieved from the map's Map.entrySet entry set is a snapshot of that
    entry's state at the time of retrieval; such entries do, however, support Map.Entry.setValue, which simply calls Map.put on the entry's key.
    
    The maps produced by `MapMaker` are serializable, and the deserialized maps retain all
    the configuration properties of the original map. During deserialization, if the original map had
    used weak references, the entries are reconstructed as they were, but it's not unlikely they'll
    be quickly garbage-collected before they are ever accessed.
    
    `new MapMaker().weakKeys().makeMap()` is a recommended replacement for java.util.WeakHashMap, but note that it compares keys using object identity whereas `WeakHashMap` uses Object.equals.

    Author(s)
    - Kevin Bourrillion

    Since
    - 2.0
    """

    def __init__(self):
        """
        Constructs a new `MapMaker` instance with default settings, including strong keys, strong
        values, and no automatic eviction of any kind.
        """
        ...


    def initialCapacity(self, initialCapacity: int) -> "MapMaker":
        """
        Sets the minimum total size for the internal hash tables. For example, if the initial capacity
        is `60`, and the concurrency level is `8`, then eight segments are created, each
        having a hash table of size eight. Providing a large enough estimate at construction time
        avoids the need for expensive resizing operations later, but setting this value unnecessarily
        high wastes memory.

        Raises
        - IllegalArgumentException: if `initialCapacity` is negative
        - IllegalStateException: if an initial capacity was already set
        """
        ...


    def concurrencyLevel(self, concurrencyLevel: int) -> "MapMaker":
        """
        Guides the allowed concurrency among update operations. Used as a hint for internal sizing. The
        table is internally partitioned to try to permit the indicated number of concurrent updates
        without contention. Because assignment of entries to these partitions is not necessarily
        uniform, the actual concurrency observed may vary. Ideally, you should choose a value to
        accommodate as many threads as will ever concurrently modify the table. Using a significantly
        higher value than you need can waste space and time, and a significantly lower value can lead
        to thread contention. But overestimates and underestimates within an order of magnitude do not
        usually have much noticeable impact. A value of one permits only one thread to modify the map
        at a time, but since read operations can proceed concurrently, this still yields higher
        concurrency than full synchronization. Defaults to 4.
        
        **Note:** Prior to Guava release 9.0, the default was 16. It is possible the default will
        change again in the future. If you care about this value, you should always choose it
        explicitly.

        Raises
        - IllegalArgumentException: if `concurrencyLevel` is nonpositive
        - IllegalStateException: if a concurrency level was already set
        """
        ...


    def weakKeys(self) -> "MapMaker":
        """
        Specifies that each key (not value) stored in the map should be wrapped in a WeakReference (by default, strong references are used).
        
        **Warning:** when this method is used, the resulting map will use identity (`==`)
        comparison to determine equality of keys, which is a technical violation of the Map
        specification, and may not be what you expect.

        Raises
        - IllegalStateException: if the key strength was already set

        See
        - WeakReference
        """
        ...


    def weakValues(self) -> "MapMaker":
        """
        Specifies that each value (not key) stored in the map should be wrapped in a WeakReference (by default, strong references are used).
        
        Weak values will be garbage collected once they are weakly reachable. This makes them a poor
        candidate for caching.
        
        **Warning:** when this method is used, the resulting map will use identity (`==`)
        comparison to determine equality of values. This technically violates the specifications of the
        methods Map.containsValue containsValue, ConcurrentMap.remove(Object, Object)
        remove(Object, Object) and ConcurrentMap.replace(Object, Object, Object) replace(K, V,
        V), and may not be what you expect.

        Raises
        - IllegalStateException: if the value strength was already set

        See
        - WeakReference
        """
        ...


    def makeMap(self) -> "ConcurrentMap"["K", "V"]:
        """
        Builds a thread-safe map. This method does not alter the state of this `MapMaker`
        instance, so it can be invoked again to create multiple independent maps.
        
        The bulk operations `putAll`, `equals`, and `clear` are not guaranteed to
        be performed atomically on the returned map. Additionally, `size` and `containsValue` are implemented as bulk read operations, and thus may fail to observe concurrent
        writes.

        Returns
        - a serializable concurrent map having the requested features
        """
        ...


    def toString(self) -> str:
        """
        Returns a string representation for this MapMaker instance. The exact form of the returned
        string is not specified.
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.AbstractBiMap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.base import Objects
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations.concurrent import LazyInit
from com.google.j2objc.annotations import RetainedWith
from com.google.j2objc.annotations import WeakOuter
from java.io import IOException
from java.io import ObjectInputStream
from java.io import ObjectOutputStream
from java.io import Serializable
from java.util import Iterator
from java.util.function import BiFunction
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class AbstractBiMap(ForwardingMap, BiMap, Serializable):
    """
    A general-purpose bimap implementation using any two backing `Map` instances.
    
    Note that this class contains `equals()` calls that keep it from supporting `IdentityHashMap` backing maps.

    Author(s)
    - Mike Bostock
    """

    def containsValue(self, value: "Object") -> bool:
        ...


    def put(self, key: "K", value: "V") -> "V":
        ...


    def forcePut(self, key: "K", value: "V") -> "V":
        ...


    def remove(self, key: "Object") -> "V":
        ...


    def putAll(self, map: dict["K", "V"]) -> None:
        ...


    def replaceAll(self, function: "BiFunction"["K", "V", "V"]) -> None:
        ...


    def clear(self) -> None:
        ...


    def inverse(self) -> "BiMap"["V", "K"]:
        ...


    def keySet(self) -> set["K"]:
        ...


    def values(self) -> set["V"]:
        ...


    def entrySet(self) -> set["Entry"["K", "V"]]:
        ...
